OC.L10N.register(
    "spreed",
    {
    "a conversation" : "mazungumzo",
    "(Duration %s)" : "(Muda %s)",
    "You attended a call with {user1}" : "Ulihudhuria simu na {user1}",
    "_%n guest_::_%n guests_" : ["%n guest","%nwageni "],
    "You attended a call with {user1} and {user2}" : "Ulihudhuria simu na {user1} na {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Ulihudhuria simu na {user1}, {user2} na {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Ulihudhuria simu na {user1}, {user2}, {user3} na {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Ulihudhuria simu na {user1}, {user2}, {user3}, {user4} na {user5}",
    "_%n other_::_%n others_" : ["%n other","%n wengine"],
    "{actor} invited you to {call}" : "{actor} alikualika kwenye {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Ulialikwa kwenye <strong>conversation</strong> au ulipigiwa <strong>simu</strong>",
    "Other activities" : "Shughuli nyingine",
    "Talk" : "Talk",
    "Guest" : "Mgeni",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Karibu kwenye Nextcloud Talk!\nKatika mazungumzo haya utaarifiwa kuhusu vipengele vipya vinavyopatikana katika Nextcloud Talk.",
    "## New in Talk %s" : "## Mpya katika Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge na Safari sasa zinaweza kutumika kushiriki katika simu za sauti na video",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Mazungumzo ya mmoja-mmoja sasa yanaendelea na hayawezi kugeuzwa kuwa mazungumzo ya kikundi kwa bahati mbaya tena. Pia wakati mmoja wa washiriki anaondoka kwenye mazungumzo, mazungumzo hayafutwa kiotomatiki tena. Ikiwa tu washiriki wote wawili wataondoka, mazungumzo yanafutwa kutoka kwa seva",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Sasa unaweza kuwaarifu washiriki wote kwa kuchapisha \"@wote\" kwenye gumzo",
    "- With the \"arrow-up\" key you can repost your last message" : "- Kwa kitufe cha \"mshale-juu\" unaweza kutuma tena ujumbe wako wa mwisho",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk sasa inaweza kuwa na amri, kutuma \"/msaada\" kama ujumbe wa gumzo ili kuona kama msimamizi wako alisanidi baadhi",
    "- With projects you can create quick links between conversations, files and other items" : "- Kwa miradi unaweza kuunda viungo vya haraka kati ya mazungumzo, faili na vitu vingine",
    "- You can now mention guests in the chat" : "- Sasa unaweza kutaja wageni kwenye gumzo",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Mazungumzo sasa yanaweza kuwa na kushawishi. Hii itawaruhusu wasimamizi kujiunga na gumzo na kupiga simu tayari ili kuandaa mkutano, huku watumiaji na wageni wakisubiri",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Sasa unaweza kujibu ujumbe moja kwa moja kuwapa watumiaji wengine muktadha zaidi ujumbe wako unahusu nini",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Kutafuta mazungumzo na washiriki sasa pia kutachuja mazungumzo yako yaliyopo, na kurahisisha kupata mazungumzo ya awali.",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Sasa unaweza kuongeza vikundi maalum vya watumiaji kwenye mazungumzo wakati programu ya miduara imesakinishwa",
    "- Check out the new grid and call view" : "- Angalia gridi mpya na mtazamo wa simu",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Sasa unaweza kupakia na kuburuta faili moja kwa moja kutoka kwa kifaa chako hadi kwenye gumzo",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Faili zinazoshirikiwa sasa zinafunguliwa moja kwa moja ndani ya mwonekano wa gumzo na programu za watazamaji",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Sasa unaweza kutafuta gumzo na ujumbe katika utafutaji uliounganishwa kwenye upau wa juu",
    "- Spice up your messages with emojis from the emoji picker" : "- Ongeza ujumbe wako kwa emojis kutoka kwa kichagua emoji",
    "- You can now change your camera and microphone while being in a call" : "- Sasa unaweza kubadilisha kamera na maikrofoni yako ukiwa kwenye simu",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Yape mazungumzo yako muktadha fulani kwa maelezo na uufungue ili watumiaji walioingia waweze kuupata na wajiunge wenyewe",
    "- See a read status and send failed messages again" : "- Angalia hali ya kusoma na kutuma ujumbe kushindwa tena",
    "- Raise your hand in a call with the R key" : "- Inua mkono wako kwenye simu kwa kutumia kitufe cha R",
    "- Join the same conversation and call from multiple devices" : "- Jiunge na mazungumzo sawa na upige simu kutoka kwa vifaa vingi",
    "- Send voice messages, share your location or contact details" : "- Tuma ujumbe wa sauti, shiriki eneo lako au maelezo ya mawasiliano",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Ongeza vikundi kwenye mazungumzo na washiriki wapya wa kikundi wataongezwa kiotomatiki kama washiriki",
    "- A preview of your audio and video is shown before joining a call" : "- Onyesho la kukagua sauti na video yako huonyeshwa kabla ya kujiunga kwenye simu",
    "- You can now blur your background in the newly designed call view" : "- Sasa unaweza kutia ukungu mandharinyuma katika mwonekano mpya wa simu ulioundwa",
    "- Moderators can now assign general and individual permissions to participants" : "- Wasimamizi sasa wanaweza kutoa ruhusa za jumla na za kibinafsi kwa washiriki",
    "- You can now react to chat messages" : "- Sasa unaweza kujibu ujumbe wa gumzo",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Katika utepe sasa unaweza kupata muhtasari wa vipengee vya hivi punde vilivyoshirikiwa",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Tumia kura ya maoni kukusanya maoni ya wengine au kusuluhisha tarehe",
    "- Configure an expiration time for chat messages" : "- Sanidi muda wa mwisho wa ujumbe wa gumzo",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Anzisha simu bila kuwaarifu wengine katika mazungumzo makubwa. Unaweza kutuma arifa za simu mahususi punde tu simu imeanza.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Tuma ujumbe wa gumzo bila kuwaarifu wapokeaji ikiwa sio haraka",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Emoji sasa zinaweza kukamilishwa kiotomatiki kwa kuandika \":\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Unganisha vipengee mbalimbali kwa kutumia kichaguzi mahiri kwa kuandika \"/\"",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Wasimamizi sasa wanaweza kuunda vyumba vifupi (inahitaji hali ya nyuma ya utendaji wa Juu)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Simu sasa zinaweza kurekodiwa (inahitaji hali ya nyuma ya utendaji wa hali ya juu)",
    "- Conversations can now have an avatar or emoji as icon" : "- Mazungumzo sasa yanaweza kuwa na avatar au emoji kama ikoni",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Mandhari pepe sasa yanapatikana pamoja na mandharinyuma yenye ukungu katika simu za video",
    "- Reactions are now available during calls" : "- Majibu sasa yanapatikana wakati wa simu",
    "- Typing indicators show which users are currently typing a message" : "- Viashirio vya kuandika vinaonyesha ni watumiaji gani wanaandika ujumbe kwa sasa",
    "- Groups can now be mentioned in chats" : "- Vikundi sasa vinaweza kutajwa kwenye gumzo",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Rekodi za simu hunakiliwa kiotomatiki ikiwa programu ya mtoaji wa unukuzi imesajiliwa",
    "- Chat messages can be translated if a translation provider app is registered" : "- Ujumbe wa gumzo unaweza kutafsiriwa ikiwa programu ya mtoaji tafsiri imesajiliwa",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** sasa inaweza kutumika katika _chat_ jumbe",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Webhooks sasa zinapatikana kutekeleza roboti. Tazama hati kwa habari zaidi https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Weka kikumbusho kwenye ujumbe wa gumzo ili kuarifiwa baadaye tena",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Tumia mazungumzo ya **Dokezo la kibinafsi** kuandika madokezo na kushiriki habari kati ya vifaa vyako",
    "- Captions allow to send a message with a file at the same time" : "- Manukuu yanaruhusu kutuma ujumbe na faili kwa wakati mmoja",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Video ya spika sasa inaonekana wakati unashiriki skrini na majibu ya simu yanahuishwa",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Ujumbe sasa unaweza kuhaririwa na waandishi na wasimamizi walioingia kwa saa 6",
    "- Unsent message drafts are now saved in your browser" : "- Rasimu za ujumbe ambao haujatumwa sasa zimehifadhiwa kwenye kivinjari chako",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Gumzo la maandishi sasa linaweza kufanywa kwa njia iliyoshirikishwa na seva zingine za Talk",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Wasimamizi sasa wanaweza kupiga marufuku akaunti na wageni ili kuwazuia kujiunga tena na mazungumzo",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Simu zinazokuja kutoka kwa matukio ya kalenda zilizounganishwa na uingizwaji wa nje ya ofisi sasa zinaonyeshwa kwenye mazungumzo",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Simu sasa zinaweza kufanywa kwa njia iliyoshirikishwa na seva zingine za Talk (inahitaji hali ya nyuma ya utendaji wa Juu)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Tunakuletea mteja wa eneo-kazi la Nextcloud Talk kwa Windows, macOS na Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Fanya muhtasari wa rekodi za simu na ujumbe ambao haujasomwa kwenye gumzo na Msaidizi wa Nextcloud",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Mikutano iliyoboreshwa ya kuwatambua wageni walioalikwa kupitia anwani zao za barua pepe, uingizaji wa orodha za washiriki, rasimu za kura na kupakua orodha za washiriki wa simu",
    "- Archive conversations to stay focused" : "- Hifadhi mazungumzo ili kukaa umakini",
    "- Schedule a meeting into your calendar from within a conversation" : "- Panga mkutano katika kalenda yako kutoka ndani ya mazungumzo",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Tafuta ujumbe wa mazungumzo ya sasa moja kwa moja kwenye upau wa kando wa kulia",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Tazama mazungumzo zaidi kwa mtazamo wa kwanza na orodha mpya iliyounganishwa (washa katika mipangilio ya Majadiliano)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Mazungumzo ya mkutano sasa yanasawazisha kichwa na maelezo kutoka kwa kalenda na yanafichwa na kichujio cha utafutaji hadi yatakapokaribia kuanza.",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Weka alama kwenye mazungumzo kuwa nyeti katika mipangilio ya arifa, ili kuficha maudhui ya ujumbe kutoka kwa orodha ya mazungumzo na arifa",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Ili kupokea arifa zinazotumwa na programu hata wakati huitumii wakati wa \"Do not disturb\", weka alama kwenye mazungumzo kuwa muhimu",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Ongeza washiriki wengine kwenye simu ya mmoja-kwa-mmoja ili kuunda simu mpya ya kikundi kwa kuruka",
    "- Use threads to keep your chat and discussions organized" : "- Tumia nyuzi kuweka gumzo na mijadala yako kupangwa",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Unukuzi wa moja kwa moja sasa unapatikana wakati wa simu (inahitaji unukuzi wa moja kwa moja wa ExApp na utendakazi wa hali ya juu nyuma)",
    "_All %n participant_::_All %n participants_" : ["All %n participant","Washiriki %n wote"],
    "Talk updates ✅" : "Masasisho ya Talk ✅",
    "Reaction deleted by author" : "Maoni yamefutwa na mwandishi",
    "{actor} created the conversation" : "{actor} alianzisha mazungumzo",
    "You created the conversation" : "Ulianzisha mazungumzo",
    "System created the conversation" : "Mfumo uliunda mazungumzo",
    "An administrator created the conversation" : "Msimamizi alianzisha mazungumzo",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} alibadilisha jina la mazungumzo kutoka \"%1$s\" mpaka \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Ulibadilisha jina la mazungumzo kutoka \"%1$s\" mpaka \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"",
    "{actor} set the description" : "{actor} ameweka maelezo",
    "You set the description" : "Umeweka maelezo",
    "An administrator set the description" : "Msimamizi aliweka maelezo",
    "{actor} removed the description" : "{actor} ameondoa maelezo",
    "You removed the description" : "Umeondoa maelezo",
    "An administrator removed the description" : "Msimamizi aliondoa maelezo",
    "You started a silent call" : "Ulianzisha simu ya kimya",
    "Outgoing silent call" : "Simu ya kimya inayotoka",
    "{actor} started a silent call" : "{actor} alianza kuita kimya kimya ",
    "Incoming silent call" : "Simu ya kimya inayoingia",
    "You started a call" : "Umepiga simu",
    "Outgoing call" : "Simu inayotoka",
    "{actor} started a call" : "{actor} alianza simu",
    "Incoming call" : "Simu inaingia",
    "{actor} joined the call" : "{actor} amejiunga kwenye simu",
    "You joined the call" : "Umejiunga kwenye simu",
    "{actor} left the call" : "{actor} ameacha simu",
    "You left the call" : "Umeacha simu",
    "{actor} unlocked the conversation" : "{actor} amefungua mazungumzo",
    "You unlocked the conversation" : "Umefungua mazungumzo",
    "An administrator unlocked the conversation" : "Msimamizi alifungua mazungumzo",
    "{actor} locked the conversation" : "{actor} amefunga mazungumzo",
    "You locked the conversation" : "Umefunga mazungumzo",
    "An administrator locked the conversation" : "Msimamizi alifunga mazungumzo",
    "{actor} limited the conversation to the current participants" : "{actor} amepunguza mazungumzo kwa washiriki wa sasa",
    "You limited the conversation to the current participants" : "Umeweka mazungumzo kwa washiriki wa sasa",
    "An administrator limited the conversation to the current participants" : "Msimamizi alizuia mazungumzo kwa washiriki wa sasa",
    "{actor} opened the conversation to registered users" : "{actor} alifungua mazungumzo kwa watumiaji waliojiandikisha",
    "You opened the conversation to registered users" : "Ulifungua mazungumzo kwa watumiaji waliojiandikisha",
    "An administrator opened the conversation to registered users" : "Msimamizi alifungua mazungumzo kwa watumiaji waliojiandikisha",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} alifungua mazungumzo kwa watumiaji waliojiandikisha na watumiaji walioundwa na programu ya Wageni",
    "You opened the conversation to registered users and users created with the Guests app" : "Umefungua mazungumzo kwa watumiaji na watumiaji waliojiandikisha ulioundwa na programu ya Wageni",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Msimamizi alifungua mazungumzo kwa watumiaji waliojiandikisha na watumiaji walioundwa na programu ya Wageni",
    "The conversation is now open to everyone" : "Mazungumzo sasa yako wazi kwa kila mtu",
    "{actor} opened the conversation to everyone" : "{actor} alifungua mazungumzo kwa kila mtu",
    "You opened the conversation to everyone" : "Ulifungua mazungumzo kwa kila mtu",
    "{actor} restricted the conversation to moderators" : "{actor} alizuia mazungumzo kwa wasimamizi",
    "You restricted the conversation to moderators" : "Ulizuia mazungumzo kwa wasimamizi",
    "{actor} started breakout rooms" : "{actor} ameanzisha vyumba vya kujitenga",
    "You started breakout rooms" : "Umeanzisha vyumba vya kujitenga",
    "{actor} stopped breakout rooms" : "{actor}alisimamisha vyumba vya vikundi ",
    "You stopped breakout rooms" : "Ulisimamisha vyumba vya vikundi",
    "{actor} allowed guests" : "{actor} aliruhusu wageni ",
    "You allowed guests" : "Uliruhusu wageni",
    "An administrator allowed guests" : "Msimamizi aliruhusu wageni",
    "{actor} disallowed guests" : "{actor}amekataza wageni ",
    "You disallowed guests" : "Umekataza wageni",
    "An administrator disallowed guests" : "Msimamizi amekataza wageni",
    "{actor} set a password" : "{actor}ameweka nenosiri ",
    "You set a password" : "Umeweka nenosiri",
    "An administrator set a password" : "Msimamizi ameweka nenosiri",
    "{actor} removed the password" : "{actor}ameondoa nenosiri ",
    "You removed the password" : "Umeondoa nenosiri",
    "An administrator removed the password" : "Msimamizi aliondoa nenosiri",
    "{actor} added {user}" : "{actor} alimwongeza {user}",
    "You joined the conversation" : "Ulijiunga na mazungumzo",
    "{actor} joined the conversation" : "{actor} alijiunga na mazungumzo",
    "You added {user}" : "Ulimwongeza {user}",
    "{actor} added you" : "{actor} alikuongeza ",
    "An administrator added you" : "Msimamizi alikuongeza",
    "An administrator added {user}" : "Msimamizi alimwongeza {user}",
    "You left the conversation" : "Uliacha mazungumzo",
    "{actor} left the conversation" : "{actor} aliacha mazungumzo",
    "{actor} removed {user}" : "{actor} alimwondoa {user}",
    "You removed {user}" : "Ulimwondoa{user}",
    "{actor} removed you" : "{actor} alikuondoa ",
    "An administrator removed you" : "Msimamizi alikuondoa",
    "An administrator removed {user}" : " Msimamizi amemwondoa {user}",
    "{actor} invited {federated_user}" : "{actor} alimwalika {federated_user}",
    "You invited {federated_user}" : "Ulimwalika {federated_user}",
    "You accepted the invitation" : "Ulikubali mwaliko",
    "{actor} invited you" : "{actor} invited you",
    "An administrator invited you" : "An administrator invited you",
    "An administrator invited {federated_user}" : "Msimamizi amemwalika {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user}alikubali mwaliko ",
    "{actor} removed {federated_user}" : "{actor} removed {federated_user}",
    "You removed {federated_user}" : "Ulimwondoa {federated_user}",
    "You declined the invitation" : "Ulikataa mwaliko",
    "An administrator removed {federated_user}" : "Msimamizi amemwondoa {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} alikataa mwaliko ",
    "{actor} added group {group}" : "{actor} aliongeza kikundi {group}",
    "You added group {group}" : "Uliongeza kikundi {group}",
    "An administrator added group {group}" : "Msimamizi aliongeza kikundi {group}",
    "{actor} removed group {group}" : "{actor} aliondoa kundi {group}",
    "You removed group {group}" : "Uliondoa kundi {group}",
    "An administrator removed group {group}" : "Msimamizi aliondoa kikundi {group}",
    "{actor} added team {circle}" : "{actor} aliongeza timu {circle}",
    "You added team {circle}" : "Ulkongeza timu {circle}",
    "An administrator added team {circle}" : "Msimamizi aliongeza timu {circle}",
    "{actor} removed team {circle}" : "{actor} aliondoa timu {circle}",
    "You removed team {circle}" : "Umeondoa timu {circle}",
    "An administrator removed team {circle}" : "Msimamizi aliondoa timu {circle}",
    "{actor} added {phone}" : "{actor} alimwongeza {phone}",
    "You added {phone}" : "Ulimwongeza {phone}",
    "An administrator added {phone}" : "Msimamizi alimwongeza {phone}",
    "{actor} removed {phone}" : "{actor} amemwondoa {phone}",
    "You removed {phone}" : "Umemwondoa {phone}",
    "An administrator removed {phone}" : "Msimamizi amemwondoa {phone}",
    "{actor} promoted {user} to moderator" : "{actor} alipandishwa cheo {user} kuwa msimamizi",
    "You promoted {user} to moderator" : "Ulimpandisha hadhi {user} kuwa msimamizi",
    "{actor} promoted you to moderator" : "{actor} alikupandisha cheo na kuwa msimamizi",
    "An administrator promoted you to moderator" : "Msimamizi alikupandisha cheo na kuwa msimamizi",
    "An administrator promoted {user} to moderator" : "Msimamizi alimpandisha cheo{user} kuwa msimamizi",
    "{actor} demoted {user} from moderator" : "{actor} amemshusha cheo{user} kutoka kwa msimamizi",
    "You demoted {user} from moderator" : "Umemshusha {user} kutoka kwa msimamizi",
    "{actor} demoted you from moderator" : "{actor} amekushusha cheo kutoka kwa msimamizi",
    "An administrator demoted you from moderator" : "Msimamizi amekushusha kutoka kwa msimamizi",
    "An administrator demoted {user} from moderator" : "Msimamizi alimshusha {user} kutoka kwa msimamizi",
    "{actor} shared a file which is no longer available" : "{actor} alishiriki faili ambayo haipatikani tena ",
    "You shared a file which is no longer available" : "Umeshiriki faili ambayo haipatikani tena",
    "File shares are currently not supported in federated conversations" : "Ushiriki wa faili kwa sasa hautumiki katika mazungumzo yaliyoshirikishwa",
    "The shared location is malformed" : "Eneo lililoshirikiwa lina hitilafu",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} amesanidi Matterbridge ili kusawazisha mazungumzo haya na gumzo zingine",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Umeweka mipangilio ya Matterbridge ili kusawazisha mazungumzo haya na gumzo zingine",
    "{actor} created thread {title}" : "{actor}aliunda mazungumzo {title}",
    "You created thread {title}" : "Uliunda mazungumzo {title}",
    "{actor} renamed thread {title}" : "{actor} amebadilisha jina la mazungumzo {title}",
    "You renamed thread {title}" : "Umebadilisha jina la mazungumzo {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} alisasisha usanidi wa Matterbridge",
    "You updated the Matterbridge configuration" : "Ulisasisha usanidi wa Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} ameondoa usanidi wa Matterbridge",
    "You removed the Matterbridge configuration" : "Umeondoa usanidi wa Matterbridge",
    "{actor} started Matterbridge" : "{actor} ameanzisha Matterbridge",
    "You started Matterbridge" : "Umeanzisha Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} alisimamisha Matterbridge",
    "You stopped Matterbridge" : "Ulisimamisha Matterbridge",
    "{actor} deleted a message" : "{actor} amefuta ujumbe",
    "You deleted a message" : "Umefuta ujumbe",
    "{actor} edited a message" : "{actor} amehariri ujumbe",
    "You edited a message" : "Umehariri ujumbe",
    "{actor} deleted a reaction" : "{actor} amefuta maoni",
    "You deleted a reaction" : "Umefuta maoni",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["You set the message expiration to %n week","Umeweka muda wa mwisho wa ujumbe kuwa wiki %n"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["You set the message expiration to %n day","Umeweka muda wa mwisho wa ujumbe kuwa siku %n"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["You set the message expiration to %n hour","Umeweka muda wa mwisho wa ujumbe kuwa saa %n"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["You set the message expiration to %n minute","Umeweka muda wa mwisho wa ujumbe kuwa dakika %n"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} set the message expiration to %n week","{actor} amweka muda wa mwisho wa ujumbe kuwa wiki %n"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} set the message expiration to %n day","{actor} ameweka muda wa mwisho wa ujumbe kuwa siku %n"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} set the message expiration to %n hour","{actor} weka muda wa mwisho wa ujumbe kuwa saa %n"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} set the message expiration to %n minute","{actor} ameweka muda wa mwisho wa ujumbe kuwa dakika %n"],
    "{actor} disabled message expiration" : "{actor} amezima muda wa kuisha kwa ujumbe",
    "You disabled message expiration" : "Umezima muda wa kuisha kwa ujumbe",
    "{actor} cleared the history of the conversation" : "{actor} amefuta historia ya mazungumzo",
    "You cleared the history of the conversation" : "Umefuta historia ya mazungumzo",
    "{actor} set the conversation picture" : "{actor} anaweka picha ya mazungumzo",
    "You set the conversation picture" : "Unaweka picha ya mazungumzo",
    "{actor} removed the conversation picture" : "{actor} ameondoa picha ya mazungumzo ",
    "You removed the conversation picture" : "Umeondoa picha ya mazungumzo",
    "{actor} ended the poll {poll}" : "{actor} alimaliza kupiga kura {poll}",
    "You ended the poll {poll}" : "Umemaliza kupiga kura {poll}",
    "{actor} started the video recording" : "{actor} ameanza kurekodi video",
    "You started the video recording" : "Umeanza kurekodi video",
    "{actor} stopped the video recording" : "{actor} amesimamisha kurekodi video",
    "You stopped the video recording" : "Umesimamisha kurekodi video",
    "{actor} started the audio recording" : "{actor} ameanza kurekodi sauti",
    "You started the audio recording" : "Umeanza kurekodi sauti",
    "{actor} stopped the audio recording" : "{actor} stopped the audio recording",
    "You stopped the audio recording" : "Umesimamisha kurekodi sauti",
    "The recording failed" : "Imeshindwa kurekodi",
    "Someone voted on the poll {poll}" : "Mtu alipiga kura kwenye kura {poll}",
    "Message deleted by author" : "Ujumbe umefutwa na mwandishi",
    "Message deleted by {actor}" : "Ujumbe ulifutwa na {actor}",
    "Message deleted by you" : "Ujumbe umefutwa na wewe",
    "Deleted user" : "Mtumiaji aliyefutwa",
    "Unknown number" : "Nambari isiyojulikana",
    "Administration" : "Utawala",
    "System" : "Mfumo",
    "%s (guest)" : "%s (mgeni)",
    "Missed call" : "Simu ambayo haikujibiwa",
    "Unanswered call" : "Simu ambayo haikupokelewa",
    "Call ended (Duration {duration})" : "Simu imekatika (Duration {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Simu ilikatwa, kwani ilifikia upeo wa muda wa simu (Duration {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} alikata simu (Duration {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})","Simu na %nwageni ilikatishwa, kwa kuwa ilifikia upeo wa muda wa simu (Duration {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Call with %n guest ended (Duration {duration})","Simu na %n wageni ilimalizika (Duration {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} ended the call with %n guest (Duration {duration})","{actor} alimaliza simu na %n wageni (Duration {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Simu na {user1} ilikamilika, kwani ilifikia upeo wa muda wa simu  (Duration {duration})",
    "Call with {user1} ended (Duration {duration})" : "Simu na {user1} ilimalizika (Duration {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} alimaliza simu na {user1} (Duration {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Simu na {user1} na {user2} ilikamilika, kwani ilifikia upeo wa muda wa simu (Duration {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Simu na {user1} na {user2} iliisha (Duration {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} amemaliza simu na  {user1} na {user2} (Duration {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Simu na {user1}, {user2}na  {user3} ilikamilika, kwani ilifikia upeo wa muda wa simu (Duration {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Simu na{user1}, {user2}na  {user3}ilimalizika  (Duration {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} alimaliza simu na {user1}, {user2} na {user3} (Duration {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Simu na {user1}, {user2}, {user3} and {user4} ilikamilika, kwani ilifikia upeo wa muda wa simu (Duration {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Simu na {user1}, {user2}, {user3} and {user4} iliisha (Duration {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} alimaliza simu na  {user1}, {user2}, {user3} na {user4} (Duration {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Simu na {user1}, {user2}, {user3}, {user4} and {user5}ilikamilika, kwani ilifikia upeo wa muda wa simu (Muda {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Simu na {user1}, {user2}, {user3}, {user4} and {user5} imeisha  (Muda {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} alimaliza simu na {user1}, {user2}, {user3}, {user4} na{user5} (Muda {duration})",
    "Message of {user} in {conversation}" : "Ujumbe wa {user} katika {conversation}",
    "Message of {user}" : "Ujumbe wa {user}",
    "Message of a deleted user in {conversation}" : "Ujumbe wa mtumiaji aliyefutwa katika {conversation}",
    "Talk conversations" : "Mazungumzo ya Talk",
    "Talk to %s" : "Talk kwa %s",
    "An error occurred. Please contact your administrator." : "Hitilafu imetokea. Tafadhali wasiliana na msimamizi wako.",
    "Storage quota exceeded" : "Kiasi cha hifadhi kimepitwa",
    "File not found" : "Faili halipatikani",
    "File is not shared, or shared but not with the user" : "Faili haijashirikiwa, au kushirikiwa lakini sio na mtumiaji",
    "No account available to delete." : "Hakuna akaunti inayopatikana ya kufuta.",
    "Poll" : "Kura ya maoni",
    "Password needs to be set" : "Nenosiri linahitaji kuwekwa",
    "Uploading the file failed" : "Imeshindwa kupakia faili",
    "No image file provided" : "Hakuna faili ya picha iliyotolewa",
    "File is too big" : "Faili ni kubwa mno",
    "Invalid file provided" : "Faili iliyotolewa si halali",
    "Invalid image" : "Taswira si halisi",
    "Unknown filetype" : "Aina ya faili haijulikani",
    "Talk mentions" : "Mitajo ya Talk",
    "More conversations" : "Mazungumzo zaidi",
    "Say hi to your friends and colleagues!" : "Sema hi kwa marafiki zako na wenzako!",
    "No unread mentions" : "Hakuna mtajo ambao haujasomwa",
    "Call in progress" : "Simu inaendelea",
    "You were mentioned" : "Ulitajwa",
    "Write to conversation" : "Andika kwa mazungumzo",
    "Writes event information into a conversation of your choice" : "Inandika habari ya tukio kwenye mazungumzo unayopenda",
    "Missing email field in header line" : "Sehemu ya barua pepe inayokosekana katika kichwa cha habari",
    "Following lines are invalid: %s" : "Mistari ifuatayo ni batili: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s amekualika kwenye mazungumzo \"%2$s\".",
    "You were invited to conversation \"%s\"." : "Ulialikwa kwenye mazungumzo \"%s\".",
    "Conversation invitation" : "Mwaliko wa mazungumzo",
    "Scheduled time" : "Muda uliopangwa",
    "Description" : "Maelezo",
    "You can also dial-in via phone with the following details" : "Unaweza pia kupiga simu kupitia simu na maelezo yafuatayo",
    "Dial-in information" : "Maelezo ya kupiga simu",
    "Meeting ID" : "Kitambulisho cha Mkutano",
    "Your PIN" : "PIN yako",
    "Click the button below to join the lobby now." : "Bofya kitufe kilicho hapa chini ili kujiunga na kushawishi sasa.",
    "Click the link below to join the lobby now." : "Bofya kiungo hapa chini ili kujiunga na kushawishi sasa.",
    "Join lobby for \"%s\"" : "Jiunge na kushawishi kwa \"%s\"",
    "Click the button below to join the conversation now." : "Bofya kitufe kilicho hapa chini ili kujiunga na mazungumzo sasa.",
    "Click the link below to join the conversation now." : "Bofya kiungo kilicho hapa chini ili kujiunga na mazungumzo sasa.",
    "Join \"%s\"" : "Jiunge \"%s\"",
    "Meeting" : "Mkutano",
    "Password request: %s" : "Ombi la nenosiri: %s",
    "Private conversation" : "Mazungumzo ya faragha",
    "Deleted user (%s)" : "Mtumiaji aliyefutwa (%s)",
    "Failed to upload call recording" : "Imeshindwa kupakia rekodi ya simu",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Seva ya kurekodi imeshindwa kupakia rekodi ya simu {call}. Tafadhali wasiliana na utawala.",
    "Share to chat" : "Shiriki kwenye gumzo",
    "Dismiss notification" : "Ondoa arifa",
    "Call recording now available" : "Rekodi ya simu sasa inapatikana",
    "The recording for the call in {call} was uploaded to {file}." : "Rekodi ya simu katika {call} ilipakiwa {file}.",
    "Transcript now available" : "Nakala sasa inapatikana",
    "The transcript for the call in {call} was uploaded to {file}." : "Nakala ya simu katika {call} ilipakiwa kwa {file}.",
    "Failed to transcript call recording" : "Imeshindwa kunakili rekodi ya simu",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Seva imeshindwa kunakili rekodi kwenye {file} kwa simu iliyo katika {call}. Tafadhali wasiliana na utawala.",
    "Call summary now available" : "Muhtasari wa simu sasa unapatikana",
    "The summary for the call in {call} was uploaded to {file}." : "Muhtasari wa simu katika {call} ulipakiwa kwenye {file}.",
    "Failed to summarize call recording" : "Imeshindwa kufanya muhtasari wa kurekodi simu",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Seva imeshindwa kufanya muhtasari wa rekodi kwenye {file} kwa simu katika {call}. Tafadhali wasiliana na utawala.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} amekualika kujiunga {roomName} kwenye {remoteServer}",
    "Accept" : "Kubali",
    "Decline" : "Kataa",
    "{user1} invited you to a federated conversation" : "{user1} alikualika kwenye mazungumzo ya shirikisho",
    "Someone reacted" : "Mtu fulani alijibu",
    "New message" : "Ujumbe mpya",
    "Reminder" : "Kikumbushio",
    "Someone mentioned you" : "Mtu alikutaja",
    "Notification" : "Taarifa",
    "Someone reacted in a private conversation" : "Mtu alijibu katika mazungumzo ya faragha",
    "You received a message in a private conversation" : "Umepokea ujumbe katika mazungumzo ya faragha",
    "Reminder in a private conversation" : "Kikumbusho katika mazungumzo ya faragha",
    "Someone mentioned you in a private conversation" : "Mtu fulani alikutaja katika mazungumzo ya faragha",
    "Notification in a private conversation" : "Arifa katika mazungumzo ya faragha",
    "Reminder: You in {call}" : "Kikumbusho: Wewe katika {call}",
    "Reminder: {user} in {call}" : "Kikumbusho: {user} katika {call}",
    "Reminder: Deleted user in {call}" : "Kikumbusho: Mtumiaji aliyefutwa kwenye {call}",
    "Reminder: {guest} (guest) in {call}" : "Kikumbusho: {guest} (mgeni) kwenye {call}",
    "Reminder: Guest in {call}" : "Kikumbusho: Mgeni kwenye {call}",
    "{user} reacted with {reaction}" : "{user}alijibizana na  {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} alijibizana na {reaction} katika {call}",
    "Deleted user reacted with {reaction} in {call}" : "Mtumiaji aliyefutwa alijibizana na {reaction} katika {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (mgeni) alijibishana na {reaction} katika {call}",
    "Guest reacted with {reaction} in {call}" : "Mgeni alijibishana na {reaction} katika {call}",
    "{user} in {call}" : "{user} katika {call}",
    "Deleted user in {call}" : "Mtumiaji aliyefutwa kwenye {call}",
    "{guest} (guest) in {call}" : "{guest} (mgeni) katika {call}",
    "Guest in {call}" : "Mgeni katika {call}",
    "{user} sent you a private message" : "{user} alikutumia ujumbe wa faragha",
    "{user} sent a message in conversation {call}" : "{user} alituma ujumbe katika mazungumzo {call}",
    "A deleted user sent a message in conversation {call}" : " Mtumiaji aliyefutwa alituma ujumbe kwenye mazungumzo {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (mgeni) alituma ujumbe katika mazungumzo {call}",
    "A guest sent a message in conversation {call}" : "Mgeni alituma ujumbe katika mazungumzo {call}",
    "{user} replied to your private message" : "{user} alijibu ujumbe wako binafsi",
    "{user} replied to your message in conversation {call}" : "{user} alijibu ujumbe wako katika mazungumzo {call}",
    "A deleted user replied to your message in conversation {call}" : "Mtumiaji aliyefutwa alijibu ujumbe wako kwenye mazungumzo {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest}(mgeni) alijibu ujumbe wako katika mazungumzo {call}",
    "A guest replied to your message in conversation {call}" : "Mgeni alijibu ujumbe wako katika mazungumzo {call}",
    "Reminder: You in private conversation {call}" : "Kikumbusho: Wewe katika mazungumzo ya faragha {call}",
    "Reminder: A deleted user in private conversation {call}" : "Kikumbusho: Mtumiaji aliyefutwa katika mazungumzo ya faragha {call}",
    "Reminder: {user} in private conversation" : "Kikumbusho: {user} katika mazungumzo ya faragha",
    "Reminder: You in conversation {call}" : "Kikumbusho: Wewe kwenye mazungumzo {call}",
    "Reminder: {user} in conversation {call}" : "Kikumbusho: {user} katika mazungumzo {call}",
    "Reminder: A deleted user in conversation {call}" : "Kikumbusho: Mtumiaji aliyefutwa kwenye mazungumzo {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Kikumbusho: {guest}(mgeni) katika mazungumzo {call}",
    "Reminder: A guest in conversation {call}" : "Kikumbusho: Mgeni katika mazungumzo {call}",
    "{user} reacted with {reaction} to your private message" : "{user}alijibizana na  {reaction}kwa ujumbe wako wa faragha ",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} ilijibizana na {reaction} kwa ujumbe wako katika mazungumzo {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Mtumiaji aliyefutwa alijibu kwa kutumia {reaction} ujumbe wako kwenye mazungumzo {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (mgeni) alijibu kwa {reaction} ujumbe wako kwenye mazungumzo {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Mgeni alijibu kwa {reaction} ujumbe wako kwenye mazungumzo {call}",
    "{user} mentioned you in a private conversation" : "{user} alikutaja kwenye mazungumzo ya faragha",
    "{user} mentioned group {group} in conversation {call}" : "{user} alitaja kikundi {group} kwenye mazungumzo {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} alitaja timu {team} kwenye mazungumzo {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} alitaja kila mtu kwenye mazungumzo {call}",
    "{user} mentioned you in conversation {call}" : "{user} alikutaja kwenye mazungumzo {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Mtumiaji aliyefutwa alitaja kikundi cha {group} kwenye mazungumzo {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Mtumiaji aliyefutwa alitaja timu {team} kwenye mazungumzo {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Mtumiaji aliyefutwa alitaja kila mtu kwenye mazungumzo {call}",
    "A deleted user mentioned you in conversation {call}" : "Mtumiaji aliyefutwa alikutaja kwenye mazungumzo {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (mgeni) alitaja kikundi {group} kwenye mazungumzo {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (mgeni) alitaja timu {team} kwenye mazungumzo {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest}(mgeni) alitaja kila mtu katika mazungumzo {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest}(mgeni) alikutaja kwenye mazungumzo {call}",
    "A guest mentioned group {group} in conversation {call}" : "Mgeni alitaja kikundi {group} kwenye mazungumzo {call}",
    "A guest mentioned team {team} in conversation {call}" : "Mgeni alitaja timu {team} kwenye mazungumzo {call}",
    "A guest mentioned everyone in conversation {call}" : "Mgeni alitaja kila mtu kwenye mazungumzo {call}",
    "A guest mentioned you in conversation {call}" : "Mgeni alikutaja kwenye mazungumzo {call}",
    "View message" : "Tazama ujumbe",
    "Dismiss reminder" : "Ondoa kikumbusho",
    "View chat" : "Tazama gumzo",
    "{user} invited you to a group conversation: {call}" : "{user}alikualika kwenye mazungumzo ya kikundi: {call}",
    "Join call" : "Jiunge katika muito",
    "Answer call" : "Jibu simu",
    "{user} would like to talk with you" : "{user} ningependa kuzungumza na wewe",
    "Call back" : "Piga simu tena",
    "You missed a call from {user}" : "Ulikosa simu kutoka {user}",
    "Accept call" : "Pokea simu",
    "Incoming phone call from {call}" : "Simu inayoingia kutoka {call}",
    "You missed a phone call from {call}" : "Ulikosa simu kutoka {call}",
    "A group call has started in {call}" : "Simu ya kikundi imeanza {call}",
    "You missed a group call in {call}" : "Ulikosa simu ya kikundi katika {call}",
    "{email} is requesting the password to access {file}" : "{email} inaomba nenosiri ili kufikia {file}",
    "{email} tried to request the password to access {file}" : "{email} alijaribu kuomba nenosiri ili kufikia {file}",
    "Someone is requesting the password to access {file}" : "Mtu anaomba nenosiri ili kufikia {file}",
    "Someone tried to request the password to access {file}" : " Mtu alijaribu kuomba nenosiri ili kufikia {file}",
    "Open settings" : "Mipangilio ya wazi",
    "Hosted signaling server added" : "iliyopangishwa imeongezwa",
    "The hosted signaling server is now configured and will be used." : "Seva ya kuashiria iliyopangishwa sasa imesanidiwa na itatumika.",
    "Hosted signaling server removed" : "Seva ya kuashiria iliyopangishwa imeondolewa",
    "The hosted signaling server was removed and will not be used anymore." : "Seva ya kuashiria iliyopangishwa iliondolewa na haitatumika tena.",
    "Hosted signaling server changed" : "Seva ya kuashiria iliyopangishwa imebadilishwa",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Akaunti ya seva inayopangishwa imebadilisha hali kutoka \"{oldstatus}\" mpaka \"{newstatus}\".",
    "pending" : "inayosubiri",
    "active" : "hai",
    "expired" : "iliyoisha muda",
    "blocked" : "iliyozuiliwa",
    "error" : "hitilafu",
    "The certificate of {host} expires in {days} days" : "Muda wa cheti cha {host} utakwisha baada ya siku {days}",
    "The certificate of {host} expired" : "Cheti cha {host} muda wake umekwisha",
    "Contact via Talk" : "Wasiliana kupitia Talk",
    "Open Talk" : "Fungua Talk",
    "Default" : "Chaguo msingi",
    "Presentation" : "Wasilisho",
    "Webinar" : "Webinar",
    "Conversations" : "Mazungumzo",
    "Messages in current conversation" : "Ujumbe katika mazungumzo ya sasa",
    "{user}" : "{user}",
    "Messages" : "Jumbe",
    "{user} in {conversation}" : "{user} katika {conversation}",
    "Messages in other conversations" : "Ujumbe katika mazungumzo mengine",
    "One-to-one rooms always need to show the other users avatar" : "Vyumba vya moja hadi moja vinahitaji kuonyesha avatar ya watumiaji wengine kila wakati",
    "Invalid emoji character" : "Herufi batili ya emoji",
    "Invalid background color" : "Rangi ya mandharinyuma si sahihi",
    "Avatar image is not square" : "Picha ya avatar si ya mraba",
    "Room {number}" : "Chumba {number}",
    "Other" : "Mengine",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Imeshindwa kuomba majaribio kwa sababu seva ya majaribio haipatikani. Tafadhali jaribu tena baadaye.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Kuna tatizo na uthibitishaji wa mfano huu. Labda haipatikani kutoka nje ili kuthibitisha URL yake.",
    "Something unexpected happened." : "Kitu kisichotarajiwa kilitokea.",
    "The URL is invalid." : "URL ni batili.",
    "An HTTPS URL is required." : "URL ya HTTPS inahitajika.",
    "The email address is invalid." : "Anwani ya barua pepe si sahihi.",
    "The language is invalid." : "Lugha ni batili.",
    "The country is invalid." : "Nchi ni batili.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Kuna tatizo na ombi la kesi. Tafadhali angalia kumbukumbu zako kwa habari zaidi.",
    "Too many requests are send from your servers address. Please try again later." : "Maombi mengi sana yanatumwa kutoka kwa anwani ya seva zako. Tafadhali jaribu tena baadaye.",
    "There is already a trial registered for this Nextcloud instance." : "Tayari kuna jaribio lililosajiliwa kwa mfano huu wa Nextcloud.",
    "Something unexpected happened. Please try again later." : "Kitu kisichotarajiwa kilitokea. Tafadhali jaribu tena baadaye.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Imeshindwa kuomba majaribio kwa sababu seva ya majaribio ilifanya kazi vibaya. Tafadhali jaribu tena baadaye.",
    "Trial requested but failed to get account information. Please check back later." : "Jaribio liliombwa lakini halikuweza kupata maelezo ya akaunti. Tafadhali angalia tena baadaye.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Kuna tatizo katika uthibitishaji wa ombi hili. Labda haipatikani kutoka nje ili kuthibitisha URL yake.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Imeshindwa kuleta maelezo ya akaunti kwa sababu seva ya majaribio ilifanya kazi vibaya. Tafadhali angalia tena baadaye.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Kuna tatizo la kuleta maelezo ya akaunti. Tafadhali angalia kumbukumbu zako kwa habari zaidi.",
    "There is no such account registered." : "Hakuna akaunti kama hiyo iliyosajiliwa.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Imeshindwa kuleta maelezo ya akaunti kwa sababu seva ya majaribio haipatikani. Tafadhali angalia tena baadaye.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Imeshindwa kufuta akaunti ya seva iliyopangishwa. Tafadhali angalia tena baadaye.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Imeshindwa kufuta akaunti kwa sababu seva ya majaribio ilifanya kazi vibaya. Tafadhali angalia tena baadaye.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Kuna tatizo la kufuta akaunti. Tafadhali angalia kumbukumbu zako kwa habari zaidi.",
    "Too many requests are sent from your servers address. Please try again later." : "Maombi mengi sana yanatumwa kutoka kwa anwani ya seva zako. Tafadhali jaribu tena baadaye.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Imeshindwa kufuta akaunti kwa sababu seva ya majaribio haipatikani. Tafadhali angalia tena baadaye.",
    "Note to self" : "Jikumbushe",
    "A place for your private notes, thoughts and ideas" : "Mahali pa maelezo yako ya kibinafsi, mawazo na mawazo",
    "Transcript is AI generated and may contain mistakes" : "Nakala imetengenezwa na AI na inaweza kuwa na makosa",
    "Summary is AI generated and may contain mistakes" : "Muhtasari umetolewa na AI na unaweza kuwa na makosa",
    "Let's get started!" : "Hebu tuanze!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** ni jukwaa salama la mawasiliano linalojiendesha lenyewe linalounganishwa kwa urahisi na mfumo ikolojia wa Nextcloud.\n\n#### Sifa Muhimu za Nextcloud Talk:\n\n* Ongea na kutuma ujumbe katika mazungumzo ya kibinafsi na ya kikundi\n* Simu za sauti na video\n* Kushiriki faili na kuunganishwa na programu zingine za Nextcloud\n* Mipangilio ya mazungumzo inayoweza kubinafsishwa, udhibiti na udhibiti wa faragha\n* Wavuti, kompyuta ya mezani na rununu (iOS na Android)\n* Mawasiliano ya kibinafsi na salama\n\nPata maelezo zaidi katika [hati za mtumiaji](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Karibu kwenye Nextcloud Talk\n\nNextcloud Talk ni programu ya kibinafsi na yenye nguvu ya kutuma ujumbe inayounganishwa na Nextcloud. Piga gumzo katika mazungumzo ya faragha au ya kikundi, shirikiana kupitia simu za sauti na video, panga simu za wavuti na matukio, badilisha mazungumzo yako yakufae na mengine mengi.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Badilisha muundo wa maandishi ili kuunda ujumbe mzuri\n\nKatika Nextcloud Talk, unaweza kutumia sintaksia ya Markdown kuunda ujumbe wako. Kwa mfano, tumia umbizo la **bold** au *italiki*, au `angazia maandishi kama msimbo`. Unaweza kuunda majedwali na kuongeza vichwa kwenye maandishi yako.\n\nJe, unahitaji kurekebisha kosa la kuandika au kubadilisha umbizo? Hariri ujumbe wako kwa kubofya \"Hariri ujumbe\" kwenye menyu ya ujumbe.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Ongeza viambatisho na viungo\n\nAmbatisha faili kutoka kwa Nextcloud Hub yako kwa kutumia kitufe cha \"+\". Shiriki vipengee kutoka kwa Faili na programu mbalimbali za Nextcloud. Baadhi ya programu hata hutumia wijeti zinazoingiliana, kwa mfano, programu ya Maandishi.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Acha mazungumzo yatiririke: taja watumiaji, itikia ujumbe na zaidi\n\nUnaweza kutaja kila mtu kwenye mazungumzo kwa kutumia %s au kutaja washiriki mahususi kwa kuandika \"@\" na kuchagua majina yao kutoka kwenye orodha.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Unaweza kujibu ujumbe, kuzisambaza kwa gumzo na watu wengine, au kunakili maudhui ya ujumbe.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : " \n## ✨ Fanya zaidi ukitumia Smart Picker\n\nAndika kwa urahisi \"/\" au nenda kwenye menyu ya \"+\" ili kufungua Kiteua Mahiri ambapo unaweza kuambatisha maudhui mbalimbali kwenye ujumbe wako. Unaweza kusanidi Smart Picker ili uweze kuongeza vipengee kutoka kwa programu za Nextcloud, GIF, maeneo ya ramani, maudhui yanayotokana na AI na mengi zaidi.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Dhibiti mipangilio ya mazungumzo\n\nKatika menyu ya mazungumzo, unaweza kufikia mipangilio mbalimbali ili kudhibiti mazungumzo yako, kama vile:\n* Hariri maelezo ya mazungumzo\n* Dhibiti arifa\n* Tumia sheria nyingi za wastani\n* Sanidi ufikiaji na usalama\n* Wezesha roboti\n*na zaidi!",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "United Arab Emirates",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua and Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarctica",
    "Argentina" : "Argentina",
    "American Samoa" : "American Samoa",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Visiwa vya Aland",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia and Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Ubeligiji",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei Darussalam",
    "Bolivia, Plurinational State of" : "Bolivia, Plurinational State of",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius and Saba",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Botswana",
    "Belarus" : "Belarus",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Cocos (Keeling) Islands" : "Cocos (Keeling) Islands",
    "Congo, the Democratic Republic of the" : "Congo, the Democratic Republic of the",
    "Central African Republic" : "Central African Republic",
    "Congo" : "Congo",
    "Switzerland" : "Uswiss",
    "Côte d'Ivoire" : "Côte d'Ivoire",
    "Cook Islands" : "Visiwa vya Cook",
    "Chile" : "Chile",
    "Cameroon" : "Cameroon",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Visiwa vya Krismas",
    "Cyprus" : "Cyprus",
    "Czechia" : "Czechia",
    "Germany" : "Ujerumani",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denmark",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Jamhuri ya Dominica",
    "Algeria" : "Algeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Misri",
    "Western Sahara" : "Sahara Magharibi",
    "Eritrea" : "Eritrea",
    "Spain" : "Hispania",
    "Ethiopia" : "Ethiopia",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Falkland Islands (Malvinas)",
    "Micronesia, Federated States of" : "Micronesia, Federated States of",
    "Faroe Islands" : "Visiwa vya Faroe",
    "France" : "Ufaransa",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "United Kingdom of Great Britain and Northern Ireland",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "French Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Greenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Ugiriki",
    "South Georgia and the South Sandwich Islands" : "Georgia Kusini na Visiwa vya Sandwich kusini",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Visiwa vya Heard na McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Croatia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungary",
    "Indonesia" : "Indonesia",
    "Ireland" : "Ireland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "India",
    "British Indian Ocean Territory" : "British Indian Ocean Territory",
    "Iraq" : "Iraq",
    "Iran, Islamic Republic of" : "Iran, Islamic Republic of",
    "Iceland" : "Iceland",
    "Italy" : "Italia",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Cambodia",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comoros",
    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
    "Korea, Democratic People's Republic of" : "Korea, Democratic People's Republic of",
    "Korea, Republic of" : "Korea, Republic of",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Visiwa vya Cayman",
    "Kazakhstan" : "Kazakhstan",
    "Lao People's Democratic Republic" : "Lao People's Democratic Republic",
    "Lebanon" : "Lebanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Lithuania",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Morocco",
    "Monaco" : "Monaco",
    "Moldova, Republic of" : "Moldova, Republic of",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint Martin (French part)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Visiwa vya Marshall",
    "North Macedonia" : "North Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Visiwa vya Mariana kaskazini",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldives",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Kisiwa cha Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Uholanzi",
    "Norway" : "Norway",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "New Zealand",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "French Polynesia",
    "Papua New Guinea" : "Papua New Guinea",
    "Philippines" : "Philippines",
    "Pakistan" : "Pakistan",
    "Poland" : "Poland",
    "Saint Pierre and Miquelon" : "Saint Pierre and Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestine, State of",
    "Portugal" : "Ureno",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Shirikisho la Urusi",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Visiwa vya Solomon",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudan",
    "Sweden" : "Sweden",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension and Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard and Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudan kusini",
    "Sao Tome and Principe" : "Sao Tome and Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (Dutch part)",
    "Syrian Arab Republic" : "Syrian Arab Republic",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Visiwa vya Turks na Caicos",
    "Chad" : "Chad",
    "French Southern Territories" : "French Southern Territories",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisia",
    "Tonga" : "Tonga",
    "Turkey" : "Uturuki",
    "Trinidad and Tobago" : "Trinidad and Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan, Province of China",
    "Tanzania, United Republic of" : "Tanzania, United Republic of",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
    "United States of America" : "United States of America",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "Saint Vincent and the Grenadines",
    "Venezuela, Bolivarian Republic of" : "Venezuela, Bolivarian Republic of",
    "Virgin Islands, British" : "Virgin Islands, British",
    "Virgin Islands, U.S." : "Virgin Islands, U.S.",
    "Viet Nam" : "Viet Nam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis and Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Afrika ya kusini",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Background blur" : "Ukungu wa mandharinyuma",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Haikuweza kuangalia usaidizi wa kupakia WASM. Tafadhali angalia mwenyewe ikiwa seva yako ya wavuti inatumikia faili za `.wasm`.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Seva yako ya wavuti haijasanidiwa ipasavyo ili kutoa faili za `.wasm`. Hili kawaida ni suala na usanidi wa Nginx. Kwa ukungu wa mandharinyuma inahitaji marekebisho ili pia kuwasilisha faili za `.wasm`. Linganisha usanidi wako wa Nginx na usanidi uliopendekezwa katika hati zetu.",
    "Talk configuration values" : "Maadili ya usanidi wa Talk",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Kulazimisha muda wa simu kunatumika tu na mfumo wa cron. Tafadhali wezesha cron ya mfumo au uondoe usanidi wa `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Thamani ndogo za `max_call_duration` (zilizowekwa kwa sasa kuwa %d) hazitekelezeki kwa sababu ya vikwazo vya kiufundi. Kazi ya chinichini inatekelezwa tu kila dakika 5, kwa hivyo tumia kwa hatari yako mwenyewe.",
    "Federation" : "Shirikisho",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Inapendekezwa sana kusanidi \"memcache.locking\" wakati Talk Federation imewashwa.",
    "High-performance backend" : "Nyuma ya utendaji wa juu",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Hakuna mandharinyuma ya Utendaji wa Juu ambayo imesanidiwa - Kuendesha Nextcloud Talk bila utendakazi wa hali ya juu mizani tu kwa simu ndogo sana (usizidi washiriki 2-3). Tafadhali weka mipangilio ya nyuma ya Utendaji wa Juu ili kuhakikisha simu zilizo na washiriki wengi hufanya kazi bila matatizo.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Kuendesha hali ya \"conversation_cluster\" ya hali ya juu ya utendaji wa juu kumeacha kutumika na haitatumika tena katika toleo lijalo. Utendaji wa hali ya juu unaauni nguzo halisi siku hizi ambazo zinapaswa kutumika badala yake.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Kufafanua vipengele vingi vya nyuma vya utendaji wa juu kumeacha kutumika na hakutatumika tena katika toleo lijalo. Badala yake kizani cha kupakia kinapaswa kusanidiwa pamoja na seva zilizounganishwa za kuashiria na kusanidiwa katika mipangilio ya Talk.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "Ufunguo wa umma uliohifadhiwa wa algoriti iliyotumika %1$s hailingani na ufunguo wa faragha uliohifadhiwa. Endesha %2$s ili kurekebisha tatizo.",
    "High-performance backend not configured correctly. Run %s for details." : "Utendaji wa hali ya juu haujasanidiwa ipasavyo. Endesha %s kwa maelezo.",
    "High-performance backend not configured correctly" : "Utendaji wa hali ya juu haujasanidiwa ipasavyo",
    "Error: Cannot connect to server" : "Hitilafu: Haiwezi kuunganisha kwenye seva",
    "Error: Server did not respond with proper JSON" : "Hitilafu: Seva haikujibu kwa kutumia JSON sahihi",
    "Error: Certificate expired" : "Hitilafu: Cheti kimekwisha muda wake",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Hitilafu: Saa za mfumo za seva ya Nextcloud na seva ya nyuma ya utendakazi wa hali ya juu hazijasawazishwa. Tafadhali hakikisha kuwa seva zote mbili zimeunganishwa kwa seva ya saa au kusawazisha wakati wao wenyewe.",
    "Could not get version" : "Haikuweza kupata toleo",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Hitilafu: Toleo linaloendesha: {version}; Seva inahitaji kusasishwa ili iendane na toleo hili la Talk",
    "Error: Server responded with: {error}" : "Hitilafu: Seva ilijibu kwa: {error}",
    "Error: Unknown error occurred" : "Hitilafu: Hitilafu isiyojulikana imetokea",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Onyo: Toleo linaloendeshwa: {version}; Seva haiauni vipengele vyote vya toleo hili la Talk, vinakosa vipengele: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Inapendekezwa sana kusanidi akiba ya kumbukumbu wakati wa kuendesha Nextcloud Talk yenye utendakazi wa hali ya juu.",
    "Client Push" : "Msukumo wa Mteja",
    "Recording backend" : "Kurekodi nyuma",
    "Using the recording backend requires a High-performance backend." : "Kutumia mazingira ya nyuma ya kurekodi kunahitaji utendakazi wa hali ya juu.",
    "No recording backend configured" : "Hakuna mandharinyuma ya kurekodi iliyosanidiwa",
    "SIP configuration" : "Usanidi wa SIP",
    "Using the SIP functionality requires a High-performance backend." : "Kutumia utendakazi wa SIP kunahitaji utendakazi wa hali ya juu.",
    "No SIP backend configured" : "Hakuna mazingira ya nyuma ya SIP yaliyosanidiwa",
    "Invalid date, date format must be YYYY-MM-DD" : "Tarehe batili, umbizo la tarehe lazima liwe YYYY-MM-DD",
    "Conversation not found" : "Mazungumzo hayapo",
    "Path is already shared with this conversation" : "Njia tayari imeshirikiwa na mazungumzo haya",
    "Chat, video & audio-conferencing using WebRTC" : "Piga gumzo, video na mikutano ya sauti kwa kutumia WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Piga gumzo, video na mikutano ya sauti kwa kutumia WebRTC\n\n* 💬 **Chat** Nextcloud Talk inakuja na soga rahisi ya maandishi, inayokuruhusu kushiriki au kupakia faili kutoka kwenye programu yako ya Nextcloud Files au kifaa cha karibu nawe na kutaja washiriki wengine.\n* 👥 **Simu za faragha, za kikundi, za umma na zilizolindwa na nenosiri!** Alika mtu, kikundi kizima au tuma kiungo cha umma ili kualika kwenye simu.\n* 🌐 **Mazungumzo ya Shirikisho** Piga gumzo na watumiaji wengine wa Nextcloud kwenye seva zao\n* 💻 **Kushiriki skrini!** Shiriki skrini yako na washiriki wa simu yako.\n* 🚀 **Muunganisho na programu zingine za Nextcloud** kama vile Faili, Kalenda, Hali ya Mtumiaji, Dashibodi, Mtiririko, Ramani, Kiteua Mahiri, Anwani, Staha na mengine mengi.\n* 🌉 **Sawazisha na masuluhisho mengine ya gumzo** Huku [Matterbridge](https://github.com/42wim/matterbridge/) ikiunganishwa katika Talk, unaweza kusawazisha kwa urahisi masuluhisho mengine mengi ya gumzo kwenye Nextcloud Talk na kinyume chake.",
    "Leave call" : "Acha simu",
    "Navigating away from the page will leave the call in {conversation}" : "Kusogeza mbali na ukurasa kutaacha simu ndani {conversation}",
    "Stay in call" : "Kaa kwenye simu",
    "Error occurred when getting the conversation information" : "Hitilafu ilitokea wakati wa kupata maelezo ya mazungumzo",
    "Discuss this file" : "Jadili faili hii",
    "Share this file with others to discuss it" : "Shiriki faili hii na wengine ili kuijadili",
    "Share this file" : "Shiriki faili hii",
    "Join conversation" : "Jiunge na mazungumzo",
    "This conversation is password-protected." : "Mazungumzo haya yanalindwa kwa nenosiri.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Tumegundua majaribio mengi ya nenosiri batili kutoka kwa IP yako. Kwa hivyo jaribio lako linalofuata hupunguzwa hadi sekunde 30.",
    "The password is wrong. Try again." : "Nenosiri si sahihi. Jaribu tena.",
    "Password" : "Nenosiri",
    "Submit" : "Wasilisha",
    "Error requesting the password." : "Hitilafu katika kuomba nenosiri.",
    "Request password" : "Omba nenosiri",
    "This conversation has ended" : "Mazungumzo haya yameisha",
    "Error occurred when joining the conversation" : "Hitilafu ilitokea wakati wa kujiunga na mazungumzo",
    "Close Talk sidebar" : "Funga utepe wa Talk",
    "Open Talk sidebar" : "Fungua utepe wa Talk",
    "Everyone" : "Kila mmoja",
    "Users and moderators" : "Watumiaji na wasimamizi",
    "Moderators only" : "Wasimamizi pekee",
    "Disable calls" : "Zima simu",
    "Save changes" : "Hifadhi mabadiliko",
    "Saving …" : "Inahifadhi...",
    "Saved!" : "Imehifadhiwa",
    "Limit to groups" : "Kikomo kwa vikundi",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Wakati angalau kikundi kimoja kimechaguliwa, ni watu wa vikundi vilivyoorodheshwa pekee wanaoweza kuwa sehemu ya mazungumzo.",
    "Guests can still join public conversations." : "Wageni bado wanaweza kujiunga na mazungumzo ya umma.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Watumiaji ambao hawawezi kutumia Talk tena bado wataorodheshwa kama washiriki katika mazungumzo yao ya awali na pia ujumbe wao wa gumzo utahifadhiwa.",
    "Limit using Talk" : "Punguza kutumia Talk",
    "Limit creating a public and group conversation" : "Punguza kuunda mazungumzo ya umma na ya kikundi",
    "Limit creating conversations" : "Punguza kuunda mazungumzo",
    "Limit starting a call" : "Punguza kuanzisha simu",
    "Limit starting calls" : "Punguza simu za kuanza",
    "When a call has started, everyone with access to the conversation can join the call." : "Simu inapoanza, kila mtu aliye na idhini ya kufikia mazungumzo anaweza kujiunga kwenye simu.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Vijibu vifuatavyo vimesakinishwa kwenye seva hii. Katika hati unaweza kupata maelezo jinsi ya {linkstart1}kuunda bot yako{linkend} au {linkstart2}orodha ya vijibu{linkend} ili kuwasha kwenye seva yako.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Hakuna vijibu vilivyosakinishwa kwenye seva hii. Katika hati unaweza kupata maelezo jinsi ya {linkstart1}kuunda bot yako{linkend} au {linkstart2}orodha ya vijibu{linkend} ili kuwasha kwenye seva yako.",
    "Description is not provided" : "Maelezo hayajatolewa",
    "Locked for moderators" : "Imefungwa kwa wasimamizi",
    "Enabled" : "Washwa",
    "Disabled" : "Zima",
    "Bots settings" : "Mipangilio ya bots",
    "State" : "State",
    "Name" : "Jina",
    "Last error" : "Hitilafu ya mwisho",
    "Total errors count" : "Jumla ya makosa",
    "Find more bots" : "Tafuta bots zaidi",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Seva zinazoaminika zinaweza kusanidiwa katika {linkstart}Ukurasa wa mipangilio ya kushiriki{linkend}.",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Soga na simu zilizoshirikishwa tayari zinafanya kazi. Ushughulikiaji wa kiambatisho unakuja katika toleo la baadaye.",
    "Enable Federation in Talk app" : "Washa Shirikisho katika programu ya Talk",
    "Permissions" : "Ruhusa",
    "Allow users to be invited to federated conversations" : "Ruhusu watumiaji kualikwa kwenye mazungumzo ya shirikisho",
    "Allow users to invite federated users into conversation" : "Ruhusu watumiaji kuwaalika watumiaji wa shirikisho katika mazungumzo",
    "Only allow to federate with trusted servers" : "Ruhusu tu kushirikiana na seva zinazoaminika",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Wakati angalau kundi moja limechaguliwa, ni watu wa makundi yaliyoorodheshwa pekee wanaoweza kualika watumiaji wa shirikisho kwenye mazungumzo.",
    "Groups allowed to invite federated users" : "Vikundi vinavyoruhusiwa kualika watumiaji wa shirikisho",
    "Select groups …" : "Chagua vikundi …",
    "All messages" : "Jumbe zote",
    "@-mentions only" : "@-mitajo pekee",
    "Off" : "Imezimwa",
    "General settings" : "Mipangilio ya jumla",
    "Default notification settings" : "Mipangilio ya arifa chaguomsingi",
    "Default group notification" : "Arifa ya kikundi chaguomsingi",
    "Default group notification for new groups" : "Arifa chaguomsingi ya kikundi kwa vikundi vipya",
    "Integration into other apps" : "Ujumuishaji katika programu zingine",
    "Allow conversations on files" : "Ruhusu mazungumzo kwenye faili",
    "Allow conversations on public shares for files" : "Ruhusu mazungumzo kwenye faili zilizoshirikiwa na umma",
    "End-to-end encrypted calls" : "Simu zilizosimbwa kutoka mwisho hadi mwisho",
    "Enable encryption" : "Wezesha usimbaji",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Simu zilizosimbwa kuanzia mwisho hadi mwisho zenye daraja la SIP lililosanidiwa zinahitaji toleo jipya zaidi la utendakazi wa hali ya juu na daraja la SIP.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Wateja wa simu hawatumii simu zilizosimbwa kutoka mwisho hadi mwisho kwa sasa.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Kwa kubofya kitufe kilicho hapo juu, habari iliyo kwenye fomu inatumwa kwa seva za Struktur AG. Unaweza kupata maelezo zaidi kwenye {linkstart}spreed.eu{linkend}.",
    "Pending" : "Inasubiri",
    "Error" : "Hitilafu",
    "Blocked" : "Imezuiliwa",
    "Active" : "Inayotumika",
    "Expired" : "Imeisha  muda",
    "Never" : "Kamwe",
    "The trial could not be requested. Please try again later." : "Jaribio halikuweza kuombwa. Tafadhali jaribu tena baadaye.",
    "The account could not be deleted. Please try again later." : "Akaunti haikuweza kufutwa. Tafadhali jaribu tena baadaye.",
    "Hosted High-performance backend" : "Seva ya nyuma yenye utendaji wa juu iliyohifadhiwa",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Mshirika wetu Struktur AG hutoa huduma ambapo seva mwenyeji inaweza kuombwa. Kwa hili unahitaji tu kujaza fomu iliyo hapa chini na Nextcloud yako itaomba. Mara baada ya seva kusanidiwa kwa ajili yako vitambulisho vitajazwa kiotomatiki. Hii itafuta mipangilio iliyopo ya seva ya kuashiria.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Ikiwa akaunti yako ya nyuma yenye utendaji wa juu inajumuisha utendaji wa STUN na/au TURN, mipangilio itasasishwa ipasavyo.",
    "URL of this Nextcloud instance" : "URL ya mfano huu wa Nextcloud",
    "Full name of the user requesting the trial" : "Jina kamili la mtumiaji anayeomba jaribio",
    "Email of the user" : "Barua pepe ya mtumiaji",
    "Language" : "Lugha",
    "Country" : "Nchi",
    "Request signaling server trial" : "Omba majaribio ya seva ya kuashiria",
    "You can see the current status of your hosted signaling server in the following table." : "Unaweza kuona hali ya sasa ya seva yako iliyopangishwa ya kuashiria katika jedwali lifuatalo.",
    "Status" : "Wadhifa",
    "Created at" : "Imetengenezwa katika",
    "Expires at" : "Inaisha saa",
    "Limits" : "Mipaka",
    "STUN included" : "STUN imejumuishwa",
    "Yes" : "Ndiyo",
    "No" : "Hapana",
    "TURN included" : "TURN imejumuishwa",
    "Delete the signaling server account" : "Futa akaunti ya seva ya kuashiria",
    "_%n user_::_%n users_" : ["%n user","%n watumiaji"],
    "Installed version: {version}" : "Toleo lililosakinishwa: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Unaweza kusakinisha Matterbridge ili kuunganisha Nextcloud Talk kwa huduma zingine, tembelea {linkstart1}ukurasa wao wa GitHub{linkend} kwa maelezo zaidi. Kupakua na kusakinisha programu kunaweza kuchukua muda. Ikiisha, tafadhali isakinishe wewe mwenyewe kutoka kwa {linkstart2}Nextcloud App Store{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Matterbridge binary ina ruhusa zisizo sahihi. Tafadhali hakikisha kuwa faili ya jozi ya Matterbridge inamilikiwa na mtumiaji sahihi na inaweza kutekelezwa. Inaweza kupatikana katika \"/…/nextcloud/apps/talk_matterbridge/bin/\".",
    "Matterbridge binary was not found or couldn't be executed." : "Matterbridge binary haikupatikana au haikuweza kutekelezwa.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Unaweza pia kuweka njia ya Matterbridge binary kwa mikono kupitia usanidi. Angalia {linkstart}hati za muunganisho wa Matterbridge{linkend} kwa maelezo zaidi.",
    "Downloading …" : "Inapakua...",
    "Install Talk Matterbridge" : "Sakinisha Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Hitilafu ilitokea wakati wa kusakinisha programu ya Matterbridge",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Hitilafu ilitokea wakati wa kusakinisha Talk Matterbridge. Tafadhali isakinishe wewe mwenyewe",
    "Failed to execute Matterbridge binary." : "Imeshindwa kutekeleza Matterbridge binary.",
    "Matterbridge integration" : "Ujumuishaji wa Matterbridge",
    "Enable Matterbridge integration" : "Washa muunganisho wa Matterbridge",
    "Status: Checking connection" : "Hali: Inaangalia muunganisho",
    "OK: Running version: {version}" : "Sawa: Toleo linaloendesha: {version}",
    "Error: Server seems to be a Signaling server" : "Hitilafu: Seva inaonekana kama seva ya Kuashiria",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Hitilafu: Saa za mfumo za seva ya Nextcloud na seva ya nyuma ya Kurekodi hazijasawazishwa. Tafadhali hakikisha kuwa seva zote mbili zimeunganishwa kwa seva ya saa au kusawazisha wakati wao wenyewe.",
    "Recording backend URL" : "Inarekodi URL ya nyuma",
    "Validate SSL certificate" : "Thibitisha cheti cha SSL",
    "Delete this server" : "Futa seva hii",
    "Test this server" : "Jaribu seva hii",
    "Disabled for all calls" : "Imezimwa kwa simu zote",
    "Enabled for all calls" : "Imewashwa kwa simu zote",
    "Configurable on conversation level by moderators" : "Inaweza kusanidiwa kwa kiwango cha mazungumzo na wasimamizi",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "Mipangilio ya PHP \"upload_max_filesize\" au \"post_max_size\" pekee itaruhusu kupakia faili hadi {maxUpload}.",
    "Recording backend settings saved" : "Mipangilio ya mandharinyuma ya kurekodi imehifadhiwa",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Wasimamizi wataruhusiwa kuwezesha idhini kwenye kiwango cha mazungumzo. Idhini ya kurekodiwa itahitajika kwa kila mshiriki kabla ya kujiunga na kila simu kwenye mazungumzo haya.",
    "The consent to be recorded will be required for each participant before joining every call." : "Idhini ya kurekodi itahitajika kwa kila mshiriki kabla ya kujiunga na kila simu.",
    "The consent to be recorded is not required." : "Idhini ya kurekodi haihitajiki.",
    "Recording backend configuration is only possible with a High-performance backend." : "Kurekodi usanidi wa mandharinyuma kunawezekana tu kwa utendakazi wa hali ya juu.",
    "Add a new recording backend server" : "Ongeza seva mpya ya nyuma ya kurekodi",
    "Shared secret" : "Siri iliyoshirikiwa",
    "Recording consent" : "Idhini ya kurekodi",
    "Recording transcription" : "Inarekodi unukuzi",
    "Automatically transcribe call recordings with a transcription provider" : "Nakili rekodi za simu kiotomatiki na mtoaji huduma ya manukuu",
    "Automatically summarize call recordings with transcription and summary providers" : "Fanya muhtasari wa rekodi za simu kiotomatiki na watoa huduma wa manukuu na muhtasari",
    "SIP configuration saved!" : "Usanidi wa SIP umehifadhiwa!",
    "SIP configuration is only possible with a High-performance backend." : "Usanidi wa SIP unawezekana tu kwa hali ya nyuma ya utendaji wa Juu.",
    "Enable SIP Dial-out option" : "Wezesha chaguo la SIP Dial-out",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Seva ya kuashiria inahitaji kusasishwa ili kutumia kipengele cha SIP Dial-out kinachotumika.",
    "Do not show SIP Dial-out caller number" : "Usionyeshe nambari ya mpigaji simu ya SIP",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Nambari isiyojulikana inapaswa kuonekana kama \"isiyojulikana\" au \"nambari iliyozuiwa\" ili kumpigia simu mpokeaji",
    "Dial-out number" : "Nambari ya kupiga",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Nambari iliyoumbizwa ya E164 inayotumika kama nambari ya mpigaji simu mbadala kwa simu zinazotoka",
    "Dial-out prefix" : "Kiambishi awali cha kupiga",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Kiambishi awali kwa nambari ya mtumiaji iliyosanidiwa kwa simu zinazotoka (chaguo-msingi ni `+`)",
    "Restrict SIP configuration" : "Zuia usanidi wa SIP",
    "Enable SIP configuration" : "Wezesha usanidi wa SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Watumiaji wa vikundi vifuatavyo pekee ndio wanaoweza kuwezesha SIP katika mazungumzo wanayosimamia",
    "Phone number (Country)" : "Nambari ya simu (Country)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Taarifa hii hutumwa kwa barua pepe za mwaliko na pia kuonyeshwa kwenye utepe kwa washiriki wote.",
    "Nextcloud base URL" : " URL ya Nextcloud base",
    "Talk Backend URL" : "URL ya Talk Backend ",
    "WebSocket URL" : "URL ya WebSocket",
    "Available features" : "Vipengele vinavyopatikana",
    "Error: Websocket connection failed" : "Hitilafu: Muunganisho wa Websocket haukufaulu",
    "Error code" : "Msimbo wa hitilafu",
    "Error message" : "Ujumbe wa hitilafu",
    "Error: Websocket connection failed. Check browser console" : "Hitilafu: Muunganisho wa Websocket haukufaulu. Angalia koni ya kivinjari",
    "High-performance backend URL" : "URL ya nyuma ya utendaji wa juu",
    "Missing High-performance backend warning hidden" : "Onyo la utendakazi wa hali ya juu halipo limefichwa",
    "High-performance backend settings saved" : "Mipangilio ya utendakazi wa hali ya juu imehifadhiwa",
    "Nextcloud Talk setup not complete" : "Usanidi wa Nextcloud Talk haujakamilika",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Tafadhali kumbuka kuwa katika simu zilizo na zaidi ya washiriki 2 bila utendakazi wa hali ya juu, kuna uwezekano mkubwa wa washiriki kukumbana na matatizo ya muunganisho na kusababisha mzigo mkubwa kwenye vifaa vinavyoshiriki.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Sakinisha mandhari ya nyuma ya Utendaji wa Juu ili kuhakikisha simu zilizo na washiriki wengi hufanya kazi kwa urahisi.",
    "Nextcloud portal" : "Lango la Nextcloud",
    "Quick installation guide" : "Mwongozo wa usakinishaji wa haraka",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Utendaji wa hali ya juu unahitajika kwa simu na mazungumzo na washiriki wengi. Bila ya nyuma, washiriki wote wanapaswa kupakia video zao kibinafsi kwa kila mshiriki, ambayo itawezekana kusababisha matatizo ya muunganisho na mzigo mkubwa kwenye vifaa vinavyoshiriki.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Inapendekezwa sana kusanidi akiba iliyosambazwa unapotumia Nextcloud Talk yenye utendakazi wa hali ya juu.",
    "Add High-performance backend server" : "Ongeza seva ya nyuma ya utendaji wa juu",
    "Warn about connectivity issues in calls with more than 2 participants" : "Onya kuhusu matatizo ya muunganisho katika simu zilizo na zaidi ya washiriki 2",
    "STUN server URL" : "URL ya seva ya STUN",
    "The server address is invalid" : "Anwani ya seva si sahihi",
    "STUN settings saved" : "Mipangilio ya STUN imehifadhiwa",
    "STUN servers" : "Seva za STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Seva ya STUN hutumiwa kubainisha anwani ya IP ya umma ya washiriki nyuma ya kipanga njia.",
    "Add a new STUN server" : "Ongeza seva mpya ya STUN",
    "{schema} scheme must be used with a domain" : "{schema} mpango lazima utumike na kikoa",
    "{option1} and {option2}" : "{option1} na {option2}",
    "{option} only" : "{option}tu ",
    "OK: Successful ICE candidates returned by the TURN server" : "SAWA: Wagombeaji wa ICE waliofaulu walirudishwa na seva ya TURN",
    "Error: No working ICE candidates returned by the TURN server" : "Hitilafu: Hakuna wagombeaji wa ICE wanaofanya kazi waliorejeshwa na seva ya TURN",
    "Testing whether the TURN server returns ICE candidates" : "Inajaribu kama seva ya TURN inarejesha watahiniwa wa ICE",
    "TURN server schemes" : "Mifumo ya seva ya TURN",
    "TURN server URL" : "URL ya seva ya TURN",
    "TURN server secret" : "Siri ya seva ya TURN",
    "TURN server protocols" : "Itifaki za seva ya TURN ",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Seva ya TURN inatumika kuwakilisha trafiki kutoka kwa washiriki nyuma ya ngome. Iwapo washiriki binafsi hawawezi kuunganisha kwa wengine, kuna uwezekano mkubwa wa kuhitajika seva ya TURN. Angalia {linkstart}hati hizi{linkend} kwa maagizo ya usanidi.",
    "TURN settings saved" : "Mipangilio ya TURN imehifadhiwa",
    "TURN servers" : "Seva za TURN ",
    "Add a new TURN server" : "Ongeza seva mpya ya TURN",
    "Failed" : "Imeshindwa",
    "OK" : "SAWA",
    "Checking …" : "Inakagua...",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Imeshindwa: WebAssembly imezimwa au haitumiki katika kivinjari hiki. Tafadhali washa WebAssembly au tumia kivinjari chenye usaidizi ili kufanya ukaguzi.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Imeshindwa: faili za \".wasm\" na \".tflite\" hazikurejeshwa ipasavyo na seva ya wavuti. Tafadhali angalia sehemu ya \"Mahitaji ya Mfumo\" katika hati za Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "SAWA: faili za \".wasm\" na \".tflite\" zilirejeshwa ipasavyo na seva ya wavuti.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Inaonekana kwamba usanidi wa PHP na Apache hauendani. Tafadhali kumbuka kuwa PHP inaweza kutumika tu na moduli ya MPM_PREFORK na PHP-FPM inaweza kutumika tu na sehemu ya MPM_EVENT.",
    "Web server setup checks" : "Ukaguzi wa usanidi wa seva ya wavuti",
    "Files required for virtual background can be loaded" : "Faili zinazohitajika kwa mandharinyuma pepe zinaweza kupakiwa",
    "Federated user" : "Mtumiaji aliyeshirikishwa",
    "Assign participants to rooms" : "Wape washiriki vyumba",
    "Configure breakout rooms" : "Sanidi vyumba vya vipindi vifupi",
    "Number of breakout rooms" : "Idadi ya vyumba vifupi",
    "You can create from 1 to 20 breakout rooms." : "Unaweza kuunda kutoka kwa vyumba 1 hadi 20 vya vipindi vifupi.",
    "Assignment method" : "Mbinu ya kukabidhi",
    "Automatically assign participants" : "Wape washiriki kiotomatiki",
    "Manually assign participants" : "Wagawie washiriki wewe mwenyewe",
    "Allow participants to choose" : "Ruhusu washiriki kuchagua",
    "Create rooms" : "Unda vyumba",
    "Confirm" : "Thibitisha",
    "Create breakout rooms" : "Unda vyumba vya vikundi vidogo",
    "Reset" : "Pangilia upya",
    "Delete breakout rooms" : "Futa vyumba vya vikundi",
    "Room {roomNumber}" : "Chumba {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Vyumba na mipangilio ya sasa ya vipindi vifupi itapotea",
    "Cancel" : "Ghairi",
    "Unassigned participants" : "Washiriki ambao hawajakabidhiwa",
    "Back" : "Rudi",
    "Assign" : "Kabidhi",
    "Add participant \"{user}\"" : "Ongeza mshiriki \"{user}\"",
    "Now" : "Sasa",
    "Invalid calendar selected" : "Kalenda batili imechaguliwa",
    "Invalid start time selected" : "Muda batili wa kuanza umechaguliwa",
    "Invalid end time selected" : "Umechagua muda wa mwisho usio sahihi",
    "Unknown error occurred" : "Hitilafu isiyojulikana imetokea",
    "Sending no invitations" : "Hakuna mwaliko unaotumwa",
    "{participant0} will receive an invitation" : "{participant0} atapokea mwaliko",
    "{participant0} and {participant1} will receive invitations" : "{participant0} na {participant1} watapokea mialiko",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} and %n other will receive invitations","{participant0}, {participant1} na %n wengine watapokea mialiko"],
    "Invite {user}" : "Alika {user}",
    "Invite all users and emails in this conversation" : "Alika watumiaji na barua pepe zote katika mazungumzo haya",
    "Meeting created" : "Mkutano umeundwa",
    "Upcoming meetings" : "Mikutano ijayo",
    "Loading …" : "Inapakia",
    "No upcoming meetings" : "Hakuna mikutano ijayo",
    "Schedule a meeting" : "Panga mkutano",
    "Meeting title" : "Kichwa cha mkutano",
    "From" : "Tangu/ kutoka",
    "To" : "Mpaka/ hadi",
    "Calendar" : "Kalenda",
    "Attendees" : "Wahudhuriaji",
    "No other participants to send invitations to." : "Hakuna washiriki wengine wa kutuma mialiko kwao.",
    "Add attendees" : "Ongeza wahudhuriaji",
    "Save" : "Hifadhi",
    "Search participants" : "Tafuta washiriki",
    "No results" : "Hakuna matokeo",
    "Done" : "Imefanyika",
    "Disable live transcription" : "Zima unukuzi wa moja kwa moja",
    "Raise hand" : "Inua mkono",
    "Raise hand (R)" : "Inua mkono (R)",
    "Lower hand" : "Shusha mkono",
    "Lower hand (R)" : "Shusha mkono (R)",
    "Exit full screen (F)" : "Ondoka kwenye skrini nzima (F)",
    "Full screen (F)" : "Skrini nzima (F)",
    "Speaker view" : "Mtazamo wa mzungumzaji",
    "Grid view" : "Mwonekano wa gridi",
    "Error when trying to load the available live transcription languages" : "Hitilafu wakati wa kujaribu kupakia lugha zinazopatikana za manukuu ya moja kwa moja",
    "Failed to enable live transcription" : "Imeshindwa kuwasha unukuzi wa moja kwa moja",
    "Recording consent is required" : "Idhini ya kurekodi inahitajika",
    "This conversation is read-only" : "Mazungumzo haya ni ya kusoma tu",
    "Conversation not found or not joined" : "Mazungumzo hayajapatikana au hayajaunganishwa",
    "Lobby is still active and you're not a moderator" : "Lobby bado inatumika na wewe si msimamizi",
    "Connection failed" : "Muunganisho haukufaulu",
    "Reload" : "Pakia upya",
    "{nickName} raised their hand." : "{nickName} waliinua mikono yao.",
    "A participant raised their hand." : "Mshiriki aliinua mkono wao.",
    "Collapse stripe" : "Kunja mstari",
    "Expand stripe" : "Panua mstari",
    "Previous page of videos" : "Ukurasa uliotangulia wa video",
    "Next page of videos" : "Ukurasa unaofuata wa video",
    "Connecting …" : "Inaunganisha...",
    "Calling …" : "Inaghairi...",
    "Waiting for {user} to join the call" : "Inasubiri {user} ajiunge na simu",
    "Waiting for others to join the call …" : "Inasubiri wengine wajiunge na simu…",
    "You can invite others in the participant tab of the sidebar" : "Unaweza kuwaalika wengine katika kichupo cha mshiriki cha utepe",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Unaweza kuwaalika wengine katika kichupo cha mshiriki cha utepe au kushiriki kiungo hiki ili kuwaalika wengine!",
    "Share this link to invite others!" : "Shiriki kiungo hiki ili kuwaalika wengine!",
    "Copy link" : "Nakili kiungio",
    "You are not allowed to enable audio" : "Huruhusiwi kuwasha sauti",
    "No audio. Click to select device" : "Hakuna sauti. Bofya ili kuchagua kifaa",
    "Mute audio" : "Zima sauti",
    "Mute audio (M)" : "Zima sauti (M)",
    "Unmute audio" : "Rejesha sauti",
    "Unmute audio (M)" : "Rejesha sauti (M)",
    "None" : "Hakuna",
    "Select a microphone" : "Chagua maikrofoni",
    "Select a speaker" : "Chagua mzungumzaji",
    "Check devices" : "Angalia vifaa",
    "Access to camera was denied" : "Ufikiaji wa kamera ulikataliwa",
    "Error while accessing camera: It is likely in use by another program" : "Hitilafu wakati wa kufikia kamera: Inawezekana inatumiwa na programu nyingine",
    "Error while accessing camera" : "Hitilafu wakati wa kufikia kamera",
    "You have been muted by a moderator" : "Umenyamazishwa na msimamizi",
    "Hide presenter video" : "Ficha video ya mtangazaji",
    "You are not allowed to enable video" : "Huruhusiwi kuwezesha video",
    "No video. Click to select device" : "Hakuna video. Bofya ili kuchagua kifaa",
    "Disable video" : "Zima video",
    "Disable video (V)" : "Zima video (V)",
    "Enable video" : "Washa video",
    "Enable video (V)" : " Washa video (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Washa video - Muunganisho wako utakatizwa kwa muda mfupi unapowasha video kwa mara ya kwanza",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Washa video (V) - Muunganisho wako utakatizwa kwa muda mfupi unapowasha video kwa mara ya kwanza",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Washa video. Muunganisho wako utakatizwa kwa muda mfupi unapowasha video kwa mara ya kwanza",
    "Select a video device" : "Chagua kifaa cha video",
    "Show presenter" : "Onyesha mtangazaji",
    "You" : "Wewe",
    "Mute" : "Zima",
    "Muted" : "Washa",
    "Show screen" : "Onyesha skrini",
    "Stop following" : "Acha kufuata",
    "Connection could not be established …" : "Muunganisho haukuweza kuanzishwa...",
    "Connection was lost and could not be re-established …" : "Muunganisho ulipotea na haukuweza kuanzishwa tena ...",
    "Connection could not be established. Trying again …" : "Muunganisho haukuweza kuanzishwa. Inajaribu tena...",
    "Connection lost. Trying to reconnect …" : "Muunganisho umepotea. Inajaribu kuunganisha tena...",
    "Connection problems …" : "Matatizo ya muunganisho…",
    "Collapse" : "Vunja",
    "Expand" : "Panua",
    "You need to be logged in to upload files" : "Unahitaji kuingia ili kupakia faili",
    "Drop your files to upload" : "Dondosha mafaili yako kupakia",
    "Conversation messages" : "Jumbe za mazungumzo",
    "Scroll to bottom" : "Tembeza hadi chini",
    "Post message" : "Chapisha ujumbe",
    "Federated conversation" : "Mazungumzo ya shirikisho",
    "Public conversation" : "Mazungumzo ya umma",
    "Favorite" : "Kipendwa",
    "Banned users" : "Watumiaji waliopigwa marufuku",
    "Manage the list of banned users in this conversation." : "Dhibiti orodha ya watumiaji waliopigwa marufuku katika mazungumzo haya.",
    "Manage bans" : "Dhibiti marufuku",
    "No banned users" : "Hakuna watumiaji waliopigwa marufuku",
    "Banned by:" : "Imepigwa marufuku na:",
    "Date:" : "Tarehe:",
    "Note:" : "Kumbuka:",
    "Hide details" : "Ficha maelezo",
    "Show details" : "Onesha maelezo",
    "Unban" : "Batilisha marufuku",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Unaweza kubadilisha kichwa na maelezo katika {linkstart}Kalenda ↗{linkend}.",
    "Error while updating conversation name" : "Hitilafu imetokea wakati wa kusasisha jina la mazungumzo",
    "Error while updating conversation description" : "Hitilafu imetokea wakati wa kusasisha maelezo ya mazungumzo",
    "Enter a name for this conversation" : "Weka jina la mazungumzo haya",
    "Edit conversation name" : "Hariri jina la mazungumzo",
    "Edit conversation description" : "Hariri maelezo ya mazungumzo",
    "Enter a description for this conversation" : "Weka maelezo ya mazungumzo haya",
    "Picture" : "Picha",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Vijibu vifuatavyo vinaweza kuwashwa kwenye mazungumzo haya. Wasiliana na utawala wako ili usakinishe roboti nyingi zaidi kwenye seva hii.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Hakuna vijibu vilivyosakinishwa kwenye seva hii. Wasiliana na utawala wako ili usakinishe roboti kwenye seva hii.",
    "Disable" : "Zima",
    "Enable" : "Wezesha",
    "Breakout rooms" : "Vyumba vya vikundi",
    "Manage breakout rooms" : "Dhibiti vyumba vifupi",
    "Set up breakout rooms for this conversation" : "Sanidi vyumba vya vikundi kwa mazungumzo haya",
    "Please select a valid PNG or JPG file" : "Tafadhali chagua faili sahihi ya PNG au JPG",
    "Choose your conversation picture" : "Chagua picha yako ya mazungumzo",
    "Choose" : "Chagua",
    "Error setting conversation picture" : "Hitilafu katika kuweka picha ya mazungumzo",
    "Could not set the conversation picture: {error}" : "Haikuweza kuweka picha ya mazungumzo: {error}",
    "Error cropping conversation picture" : "Hitilafu katika kupunguza picha ya mazungumzo",
    "Error removing conversation picture" : "Hitilafu katika kuondoa picha ya mazungumzo",
    "Set emoji as conversation picture" : "Weka emoji kama picha ya mazungumzo",
    "Set background color for conversation picture" : "Weka rangi ya usuli kwa picha ya mazungumzo",
    "Upload conversation picture" : "Pakia picha ya mazungumzo",
    "Choose conversation picture from files" : "Chagua picha ya mazungumzo kutoka kwa faili",
    "Remove conversation picture" : "Ondoa picha ya mazungumzo",
    "The file must be a PNG or JPG" : "Faili lazima iwe PNG au JPG",
    "Set picture" : "Weka picha",
    "Default permissions modified for {conversationName}" : "Ruhusa chaguomsingi zimerekebishwa kwa {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Haikuweza kurekebisha ruhusa chaguomsingi za {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Hariri ruhusa za msingi kwa washiriki katika mazungumzo haya. Mipangilio hii haiathiri wasimamizi.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Kila mara ruhusa zinaporekebishwa katika sehemu hii, ruhusa maalum zilizotolewa hapo awali kwa washiriki binafsi zitapotea.",
    "All permissions" : "Ruhusa zote",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Washiriki wana ruhusa ya kuanzisha simu, kujiunga na simu, kuwasha sauti na video na kushiriki skrini.",
    "Restricted" : "Imezuiliwa",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Washiriki wanaweza kujiunga na simu, lakini hawawezi kuwasha sauti wala video wala kushiriki skrini hadi msimamizi awape ruhusa mwenyewe.",
    "Advanced permissions" : "Ruhusa za hali ya juu",
    "Edit permissions" : "Hariri ruhusa",
    "Conversation settings" : "Mipangilio ya mazungumzo",
    "Basic Info" : "Maelezo ya Msingi",
    "Personal" : "Binafsi",
    "Moderation" : "Usimamizi",
    "Setup overview" : "Weka muhtasari",
    "Live transcription" : "Unukuzi wa moja kwa moja",
    "Enable live transcription" : "Washa unukuzi wa moja kwa moja",
    "Breakout Rooms" : "Vyumba vya Kuzuka",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Bots",
    "Danger zone" : "Eneo la hatari",
    "Archive conversation" : "Hifadhi mazungumzo",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Mazungumzo yaliyohifadhiwa kwenye kumbukumbu hufichwa kutoka kwa orodha ya mazungumzo kwa chaguo-msingi. Hata hivyo, bado yataonekana unapotafuta jina la mazungumzo au kufikia orodha ya mazungumzo yaliyohifadhiwa kwenye kumbukumbu.",
    "Do you really want to leave \"{displayName}\"?" : "Je, kweli unataka kuondoka \"{displayName}\"?",
    "You can archive this conversation instead." : "Unaweza kuweka mazungumzo haya kwenye kumbukumbu badala yake.",
    "Leave conversation" : "Acha mazungumzo",
    "You need to promote a new moderator before you can leave the conversation" : "Unahitaji kutangaza msimamizi mpya kabla ya kuondoka kwenye mazungumzo",
    "Delete conversation" : "Futa mazungumzo",
    "Do you really want to delete \"{displayName}\"?" : "Je, kweli unataka kufuta \"{displayName}\"?",
    "Error while deleting conversation" : "Hitilafu wakati wa kufuta mazungumzo",
    "Delete all chat messages" : "Futa ujumbe wote wa gumzo",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Je, kweli unataka kufuta barua pepe zote katika \"{displayName}\"?",
    "Error while clearing chat history" : "Hitilafu wakati wa kufuta historia ya gumzo",
    "Be careful, these actions cannot be undone." : "Kuwa mwangalifu, vitendo hivi haviwezi kutenduliwa.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Mara tu mazungumzo yamesalia, ili kujiunga tena na mazungumzo yaliyofungwa, mwaliko unahitajika. Mazungumzo ya wazi yanaweza kuunganishwa tena wakati wowote.",
    "Permanently delete this conversation." : "Futa mazungumzo haya kabisa.",
    "Delete chat messages" : "Futa ujumbe wa gumzo",
    "Permanently delete all the messages in this conversation." : "Futa kabisa ujumbe wote katika mazungumzo haya.",
    "_%n hour_::_%n hours_" : ["%n hour","%nmasaa "],
    "_%n day_::_%n days_" : ["%n day","%n siku "],
    "_%n week_::_%n weeks_" : ["%n week","%n wiki "],
    "Custom expiration time" : "Muda maalum wa kuisha",
    "Message expiration disabled" : "Muda wa kuisha kwa ujumbe umezimwa",
    "Message expiration set: {duration}" : "Muda wa kuisha kwa ujumbe umewekwa: {duration}",
    "Error when trying to set message expiration" : "Hitilafu wakati wa kujaribu kuweka muda wa mwisho wa ujumbe",
    "Message expiration" : "Muda wa ujumbe kuisha",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Muda wa ujumbe wa gumzo unaweza kuisha baada ya muda fulani. Kumbuka: Faili zinazoshirikiwa kwenye gumzo hazitafutwa kwa mmiliki, lakini hazitashirikiwa tena kwenye mazungumzo.",
    "Set message expiration" : "Weka muda wa kuisha kwa ujumbe",
    "Current message expiration" : "Muda wa kuisha kwa ujumbe wa sasa",
    "Password copied to clipboard" : "Nenosiri limenakiliwa kwenye ubao wa kunakili",
    "Password could not be copied" : "Nenosiri halikuweza kunakiliwa",
    "Guest access" : "Ufikiaji wa mgeni",
    "Breakout rooms are not allowed in public conversations." : "Vyumba vifupi haviruhusiwi katika mazungumzo ya umma.",
    "Allow guests to join this conversation via link" : "Ruhusu wageni wajiunge na mazungumzo haya kupitia kiungo",
    "Password protection" : "Ulinzi wa nenosiri",
    "This conversation is password-protected. Guests need password to join" : "Mazungumzo haya yanalindwa kwa nenosiri. Wageni wanahitaji nenosiri ili kujiunga",
    "Password protection is needed for public conversations" : "Ulinzi wa nenosiri unahitajika kwa mazungumzo ya umma",
    "Set a password" : "Weka nenosiri",
    "Change password" : "Change password",
    "Enter new password" : "Ingiza nenosiri jipya",
    "Save password" : "Hifadhi nenosiri",
    "Copy password" : "Nakili nenosiri",
    "Guests are allowed to join this conversation via link" : "Wageni wanaruhusiwa kujiunga na mazungumzo haya kupitia kiungo",
    "Guests are not allowed to join this conversation" : "Wageni hawaruhusiwi kujiunga na mazungumzo haya",
    "Resend invitations" : "Tuma mialiko upya",
    "This conversation is open to both registered users and users created with the Guests app" : "Mazungumzo haya yako wazi kwa watumiaji na watumiaji waliojiandikisha yaliyoundwa na programu ya Wageni",
    "This conversation is open to registered users" : "Mazungumzo haya yamefunguliwa kwa watumiaji waliojiandikisha",
    "This conversation is limited to the current participants" : "Mazungumzo haya ni ya washiriki wa sasa pekee",
    "You opened the conversation to both registered users and users created with the Guests app" : "Umefungua mazungumzo kwa watumiaji waliojiandikisha na watumiaji walioundwa na programu ya Wageni",
    "Error occurred when opening or limiting the conversation" : "Hitilafu ilitokea wakati wa kufungua au kupunguza mazungumzo",
    "Open conversation to registered users, showing it in search results" : "Fungua mazungumzo kwa watumiaji waliojiandikisha, ukiyaonyesha katika matokeo ya utafutaji",
    "Also open to users created with the Guests app" : "Wazi pia kwa watumiaji walioundwa na programu ya Wageni",
    "Open conversation" : "Mazungumzo ya wazi",
    "Set language spoken in calls" : "Weka lugha inayozungumzwa katika simu",
    "Languages could not be loaded" : "Lugha hazikuweza kupakiwa",
    "Loading languages …" : "Inapakia lugha  …",
    "Invalid language" : "Lugha batili",
    "Default language (English)" : "Lugha chaguo-msingi (Kiingereza)",
    "Default live transcription language set" : "Seti chaguomsingi ya lugha ya manukuu ya moja kwa moja",
    "Live transcription language set: {languageName}" : "Seti ya lugha ya manukuu ya moja kwa moja: {languageName}",
    "Error when trying to set live transcription language" : "Hitilafu wakati wa kujaribu kuweka lugha ya manukuu ya moja kwa moja",
    "Start time: {date}" : "Muda wa kuanza: {date}",
    "Start time has been updated" : "Muda wa kuanza umesasishwa",
    "Error occurred while updating start time" : "Hitilafu ilitokea wakati wa kusasisha muda wa kuanza",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Kuwasha ushawishi kutaondoa wasio wasimamizi kwenye simu inayoendelea.",
    "Enable lobby, restricting the conversation to moderators" : "Washa kushawishi, ukizuia mazungumzo kwa wasimamizi",
    "Meeting start time" : "Muda wa kuanza kwa mkutano",
    "Start time (optional)" : "Muda wa kuanza (optional)",
    "Import email participants" : "Ingiza washiriki wa barua pepe",
    "You can import a list of email participants from a CSV file." : "Unaweza kuleta orodha ya washiriki wa barua pepe kutoka katika faili ya CSV.",
    "Poll drafts" : "Rasimu za kura",
    "Browse poll drafts" : "Vinjari rasimu za kura",
    "Error occurred when locking the conversation" : "Hitilafu ilitokea wakati wa kufunga mazungumzo",
    "Error occurred when unlocking the conversation" : "Hitilafu ilitokea wakati wa kufungua mazungumzo",
    "Lock conversation" : "Funga mazungumzo",
    "This will also terminate the ongoing call." : "Hii pia itasitisha simu inayoendelea.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Funga mazungumzo ili kuzuia mtu yeyote kutuma ujumbe au kuanzisha simu",
    "Edit" : "Hariri",
    "More information" : "Taarifa zaidi",
    "Delete" : "Futa",
    "Add new bridged channel to current conversation" : "Ongeza kituo kipya kilichounganishwa kwenye mazungumzo ya sasa",
    "unknown state" : "hali isiyojulikana",
    "running" : "inafanya kazi",
    "not running, check Matterbridge log" : "Haifanyi kazi, angalia logi ya Matterbridge",
    "not running" : "Haifanyi kazi",
    "Bridge saved" : "Daraja lililohifadhiwa",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Unaweza kuunganisha vituo kutoka kwa mifumo mbalimbali ya ujumbe wa papo hapo ukitumia Matterbridge.",
    "More info on Matterbridge" : "Pata maelezo zaidi kuhusu Matterbridge",
    "Messaging systems" : "Mifumo ya ujumbe",
    "Enable bridge" : "Washa daraja",
    "Show Matterbridge log" : "Onyesha kumbukumbu ya Matterbridge",
    "Log content" : "Maudhui ya kumbukumbu",
    "Only moderators are allowed to mention @all" : "Wasimamizi pekee wanaruhusiwa kutaja @ wote",
    "All participants are allowed to mention @all" : "Washiriki wote wanaruhusiwa kutaja @wote",
    "Participants are now allowed to mention @all." : "Washiriki sasa wanaruhusiwa kutaja @wote.",
    "Mentioning @all has been limited to moderators." : "Kutaja @all kumepunguzwa kwa wasimamizi.",
    "Allow participants to mention @all" : "Ruhusu washiriki kutaja @wote",
    "Mention permissions" : "Taja ruhusa",
    "Notifications" : "Arifa",
    "Notify about calls in this conversation" : "Arifu kuhusu simu katika mazungumzo haya",
    "Important conversation" : "Mazungumzo muhimu",
    "\"Do not disturb\" user status is ignored for important conversations" : "\"Usisumbue\" hali ya mtumiaji inapuuzwa kwa mazungumzo muhimu",
    "Sensitive conversation" : "Mazungumzo nyeti",
    "Message preview will be disabled in conversation list and notifications" : "Onyesho la kuchungulia la ujumbe litazimwa katika orodha ya mazungumzo na arifa",
    "Recording consent is required for calls in this conversation" : "Idhini ya kurekodi inahitajika kwa simu katika mazungumzo haya",
    "Recording consent is not required for calls in this conversation" : "Idhini ya kurekodi haihitajiki kwa simu katika mazungumzo haya",
    "Recording consent requirement was updated" : "Masharti ya idhini ya kurekodi yalisasishwa",
    "Error occurred while updating recording consent" : "Hitilafu ilitokea wakati wa kusasisha idhini ya kurekodi",
    "Recording Consent" : "Idhini ya Kurekodi",
    "Recording consent cannot be changed once a call or breakout session has started." : "Idhini ya kurekodi haiwezi kubadilishwa mara tu simu au kipindi cha muhula kitakapoanza.",
    "Require recording consent before joining call in this conversation" : "Inahitaji idhini ya kurekodi kabla ya kujiunga na simu kwenye mazungumzo haya",
    "Recording consent is required for all calls" : "Idhini ya kurekodi inahitajika kwa simu zote",
    "SIP dial-in is now possible without PIN requirement" : "Upigaji simu wa SIP sasa unawezekana bila hitaji la PIN",
    "SIP dial-in is now enabled" : "Upigaji simu wa SIP sasa umewezeshwa",
    "SIP dial-in is now disabled" : "Upigaji simu wa SIP sasa umezimwa",
    "Error occurred when enabling SIP dial-in" : "Hitilafu ilitokea wakati wa kuwezesha upigaji simu wa SIP",
    "Error occurred when disabling SIP dial-in" : "Hitilafu ilitokea wakati wa kuzima upigaji simu wa SIP",
    "Phone and SIP dial-in" : "Upigaji simu na SIP",
    "Enable phone and SIP dial-in" : "Washa upigaji simu na SIP",
    "Allow to dial-in without a PIN" : "Ruhusu kupiga simu bila PIN",
    "Ongoing" : "Inaendelea",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n person accepted","%n watu walikubali"],
    "_%n person declined_::_%n people declined_" : ["%n person declined","%n watu walikataa"],
    "_and %n other attachment_::_and %n other attachments_" : ["and %n other attachment","na viambatisho %n vingine"],
    "With {displayName}" : "Na {displayName}",
    "In {conversation}" : "Katika {conversation}",
    "View attachment" : "Tazama kiambatisho",
    "Join" : "Jiunge",
    "View conversation" : "Tazama mazungumzo",
    "View event on Calendar" : "Tazama tukio kwenye Kalenda",
    "Error while creating the conversation" : "Hitilafu wakati wa kuunda mazungumzo",
    "Hello, {displayName}" : "Hallo, {displayName}",
    "Start meeting now" : "Anza mkutano sasa",
    "Give your meeting a title" : "Upe  kichwa mkutano wako",
    "Create and copy link" : "Unda na unakili kiungo",
    "Create a new conversation" : "Tengeneza mazungumzo mapya",
    "Join open conversations" : "Jiunge mazungumzo ya wazi",
    "Call a phone number" : "Piga nambari ya simu",
    "Scroll backward" : "Rudisha nyuma",
    "Scroll forward" : "Sogeza mbele",
    "Schedule meetings" : "Panga mikutano",
    "You don't have any upcoming meetings" : "Huna mikutano yoyote inayokuja",
    "Open calendar" : "Fungua kalenda",
    "Unread mentions" : "Mitajo ambayo haijasomwa",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Barua pepe ulizotajwa zitaonekana hapa. Unaweza kutaja watu kwa kuandika @ ikifuatiwa na majina yao",
    "Upcoming reminders" : "Vikumbusho vijavyo",
    "Message reminders" : "Vikumbusho vya ujumbe",
    "Set a reminder on a message to be notified" : "Weka kikumbusho kwenye ujumbe utakaoarifiwa",
    "Start a group conversation" : "Anzisha mazungumzo ya kikundi",
    "Create conversation" : "Tengeneza mazungumzo",
    "Enter your name" : "Ingiza jina lako",
    "Submit name and join" : "Toa jina na ujiunge",
    "Do you already have an account?" : "Je, tayari una akaunti?",
    "Log in" : "Ingia",
    "Error while verifying uploaded file" : "Hitilafu wakati wa kuthibitisha faili iliyopakiwa",
    "Uploaded file is verified" : "Faili iliyopakiwa imethibitishwa",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Umbizo la maudhui ni thamani zilizotenganishwa kwa koma (CSV):<br/>- Mstari wa kichwa unahitajika na lazima ulingane na <samp>\"jina\",\"barua pepe\"</samp> au <samp>\"barua pepe\"</samp><br/> tu - Ingizo moja kwa kila mstari (k.m. <samp>\"John Doe\",john@example.tld\"</samp>)",
    "Participants added successfully" : "Washiriki waliongezwa kwa mafanikio",
    "Error while adding participants" : "Hitilafu wakati wa kuongeza washiriki",
    "Import a file" : "Ingiza faili",
    "Browse" : "Vinjari",
    "Verifying uploaded file …" : "Inathibitisha faili iliyopakiwa...",
    "This might take a moment" : "Hii inaweza kuchukua muda",
    "Send invitations" : "Tuma mialiko",
    "_%n invalid email_::_%n invalid emails_" : ["%n invalid email","%n barua pepe zisizo sahihi"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n email is already imported or a duplicate","%n barua pepe tayari zimeagizwa kutoka nje au nakala"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n invitation can be sent","mialiko %n inaweza kutumwa"],
    "An error occurred while calling a phone number" : "Hitilafu ilitokea wakati wa kupiga nambari ya simu",
    "Phone number could not be called: {error}" : "Nambari ya simu haikuweza kuitwa: {error}",
    "Phone number could not be called" : "Nambari ya simu haikuweza kuitwa",
    "Search participants or phone numbers" : "Tafuta washiriki au nambari za simu",
    "Creating the conversation …" : "Inaunda mazungumzo...",
    "Mark as read" : "Weka alama kama iliyosomwa",
    "Mark as unread" : "Weka alama kama haijasomwa",
    "Remove from favorites" : "Ondoa kutoka katika vipendwa",
    "Add to favorites" : "Ongeza kwenye vipendwa",
    "Unarchive conversation" : "Ondoa mazungumzo kwenye kumbukumbu",
    "Ignore \"Do not disturb\"" : "Puuza \"Do not disturb\"",
    "You need to promote a new moderator before you can leave the conversation." : "Unahitaji kutangaza msimamizi mpya kabla ya kuondoka kwenye mazungumzo.",
    "Conversation actions" : "Vitendo vya mazungumzo",
    "Notify about calls" : "Arifu kuhusu simu",
    "Hide message text" : "Ficha maandishi ya ujumbe",
    "Pending invitations" : "Mialiko inayosubiri",
    "From {user} at {remoteServer}" : "Kutoka {user} kwenye {remoteServer}",
    "Decline invitation" : "Kataa mwaliko",
    "Accept invitation" : "Kubali mwaliko",
    "No pending invitations" : "Hakuna mialiko inayosubiri",
    "Home" : "Nyumbani",
    "Unread" : "Haijasomwa",
    "Mentions" : "Mitajo",
    "Meetings" : "Mikutano",
    "Alphabetically" : "Kialfabeti",
    "No followed threads" : "Hakuna nyuzi zinazofuatwa",
    "No matches found" : "Hakuna ulingano uliopatikana",
    "No conversations found" : "Hakuna mazungumzo yaliyopatikana",
    "You have no archived conversations." : "Huna mazungumzo yaliyohifadhiwa kwenye kumbukumbu.",
    "Subscribe to an existing thread or start your own." : "Jiandikishe kwa mazungumzo yaliyopo au uanzishe yako.",
    "You have no unread mentions." : "Huna mtaji ambao haujasomwa.",
    "You have no unread messages." : "Huna ujumbe ambao haujasomwa.",
    "An error occurred while performing the search" : "Hitilafu ilitokea wakati wa kutafuta",
    "Conversation list" : "Orodha ya mazungumzo",
    "Filter conversations by" : "Chuja mazungumzo kwa",
    "Unread messages" : "Jumbe ambazo hazijasomwa",
    "Meeting conversations" : "Mazungumzo ya mkutano",
    "Clear filters" : "Futa vichujio",
    "New personal note" : "Ujumbe mpya wa kibinafsi",
    "Back to conversations" : "Rudi kwenye mazungumzo",
    "Archived conversations" : "Mazungumzo yaliyowekwa kwenye kumbukumbu",
    "Threads" : "Mijadala",
    "Clear filter" : "Futa kichujio",
    "Show more threads" : "Onyesha mijadala zaidi",
    "App settings" : "Mipangilio ya programu",
    "Users" : "Watumiaji",
    "Groups" : "Makundi",
    "Teams" : "Timu",
    "Federated users" : "Watumiaji walioshirikishwa",
    "New private conversation" : "Mazungumzo mapya ya faragha",
    "Other sources" : "Vyanzo vingine",
    "Open conversations" : "Mazungumzo ya wazi",
    "No search results" : "Hakuna matokeo ya utafutaji",
    "Users, groups and teams" : "Watumiaji, vikundi na timu",
    "Users and groups" : "Watumiaji na vikundi",
    "Users and teams" : "Watumiaji na timu",
    "Groups and teams" : "Vikundi na timu",
    "New group conversation" : "Mazungumzo mapya ya kikundi",
    "The meeting will start soon" : "Mkutano utaanza hivi karibuni",
    "This meeting is scheduled for {startTime}" : "Mkutano huu umepangwa kwa {startTime}",
    "You are currently waiting in the lobby" : "Kwa sasa unasubiri kwenye chumba cha kushawishia",
    "Select microphone" : "Chagua maikrofoni",
    "No microphone available" : "Hakuna maikrofoni inayopatikana",
    "Select speaker" : "Chagua spika",
    "No speaker available" : "Hakuna spika zinazopatikana",
    "Select camera" : "Chagua kamera",
    "No camera available" : "Hakuna kamera inayopatikana",
    "Select a device" : "Chagua kifaa",
    "Playing …" : "Inacheza...",
    "Test speakers" : "Jaribu spika",
    "Test" : "Jaribu",
    "Devices" : "Vifaa",
    "Backgrounds" : "Mandhari nyuma",
    "No audio" : "Hakuna sauti",
    "No camera" : "Hakuna kamera",
    "Display video as you will see it (mirrored)" : "Onyesha video jinsi utakavyoiona (iliyoakisiwa)",
    "Display video as others will see it" : "Onyesha video jinsi wengine watakavyoiona",
    "Calls are not supported in your browser" : "Simu hazitumiki katika kivinjari chako",
    "Access to microphone is only possible with HTTPS" : "Ufikiaji wa maikrofoni unawezekana tu kwa HTTPS",
    "Access to microphone was denied" : "Ufikiaji wa maikrofoni ulikataliwa",
    "Error while accessing microphone" : "Hitilafu wakati wa kufikia maikrofoni",
    "Access to camera is only possible with HTTPS" : "Ufikiaji wa kamera unawezekana tu kwa HTTPS",
    "The call is being recorded." : "Simu inarekodiwa.",
    "The call might be recorded." : "Simu inaweza kuwa imerekodiwa",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Rekodi inaweza kujumuisha sauti yako, video kutoka kwa kamera na kushiriki skrini. Idhini yako inahitajika kabla ya kujiunga kwenye simu.",
    "Give consent to the recording of this call" : "Toa idhini ya kurekodiwa kwa simu hii",
    "Show more info" : "Onesha maelezo zaidi",
    "Audio is not available" : "Sauti haipatikani",
    "Video is not available" : "Video haipatikani",
    "Start recording immediately with the call" : "Anza kurekodi mara moja na simu",
    "Notify all participants about this call" : "Wajulishe washiriki wote kuhusu simu hii",
    "Apply settings" : "Tumia mipangilio",
    "Select virtual office background" : "Chagua mwonekano wa mandharinyuma ya ofisi",
    "Select virtual home background" : "Chagua mwonekano wa mandharinyuma ya nyumbani",
    "Select virtual abstract background" : "Chagua mwonekano wa mandharinyuma dhahania",
    "Select virtual beach background" : "Chagua mwonekano wa mandharinyuma ya ufukwe",
    "Select virtual park background" : "Chagua mwonekano wa mandharinyuma ya bustani",
    "Select virtual theater background" : "Chagua mwonekano wa mandharinyuma ya ukumbi wa michezo",
    "Select virtual library background" : "Chagua mwonekano wa mandharinyuma ya maktaba ",
    "Select virtual space station background" : "Chagua mandharinyuma ya kituo cha anga za juu",
    "Error while uploading the file" : "Hitilafu wakati wa kupakia faili",
    "Select a file" : "Chagua faili",
    "Invalid path selected" : "Njia iliyochaguliwa si halali",
    "Select virtual background from file {fileName}" : "Chagua mwonekano wa mandharinyuma  kutoka kwa faili {fileName}",
    "Blur" : "Blur",
    "Upload" : "Pakia",
    "Files" : "Faili",
    "(editing)" : "(inahariri)",
    "(edited)" : "(imehaririwa)",
    "The message has expired or has been deleted" : "Ujumbe umekwisha muda wake au umefutwa",
    "Cancel quote" : "Ghairi nukuu",
    "24 hours" : "Masaa 24",
    "7 days" : "Siku 7",
    "Until unpin" : "Until unpin",
    "Clear reminder – {timeLocale}" : "Futa kikumbusho – {timeLocale}",
    "Edited by {actor}" : "Imehaririwa na {actor}",
    "Message text copied to clipboard" : "Maandishi ya ujumbe yamenakiliwa kwenye ubao wa kunakili",
    "Message text could not be copied" : "Maandishi ya ujumbe hayakuweza kunakiliwa",
    "Message forwarded to \"Note to self\"" : "Ujumbe umetumwa kwa \"Note to self\"",
    "Error while forwarding message to \"Note to self\"" : "Hitilafu wakati wa kusambaza ujumbe kwa \"Note to self\"",
    "A reminder was successfully removed" : "Kikumbusho kiliondolewa kwa mafanikio",
    "Error occurred when removing a reminder" : "Hitilafu ilitokea wakati wa kuondoa kikumbusho",
    "A reminder was successfully set at {datetime}" : " Kikumbusho kiliwekwa kwa mafanikio {datetime}",
    "Error occurred when creating a reminder" : "Hitilafu ilitokea wakati wa kuunda kikumbusho",
    "Add a reaction to this message" : "Ongeza maoni kwa ujumbe huu",
    "Reply" : "Jibu",
    "More actions" : "Vitendo zaidi",
    "Set reminder" : "Weka ukumbusho",
    "Pin message" : "Pin message",
    "Unpin message" : "Unpin message",
    "Reply privately" : "Jibu kwa faragha",
    "Edit message" : "Hariri ujumbe",
    "Copy message" : "Nakili ujumbe",
    "Copy message link" : "Nakili kiungo cha ujumbe",
    "Go to file" : "Nenda kwenye faili",
    "Download file" : "Pakua faili",
    "Go to thread" : "Nenda kwenye mjadala",
    "Edit thread details" : "Hariri maelezo ya mjadala",
    "Forward message" : "Sambaza ujumbe",
    "Translate" : "Tafsiri",
    "Set custom reminder" : "Weka kikumbusho maalum",
    "Close reactions menu" : "Funga menyu ya maoni",
    "React with {emoji}" : "Jibu kwa {emoji}",
    "React with another emoji" : "Jibu kwa emoji nyingine",
    "Choose a conversation to forward the selected message." : "Chagua mazungumzo ili kusambaza ujumbe uliochaguliwa.",
    "Error while forwarding message" : "Hitilafu wakati wa kusambaza ujumbe",
    "The message has been forwarded to {selectedConversationName}" : "Ujumbe umetumwa kwa {selectedConversationName}",
    "Dismiss" : "Ondoa",
    "Go to conversation" : "Nenda kwenye mazungumzo",
    "Detect language" : "Lugha iliyotambuliwa",
    "The message could not be translated" : "Ujumbe haukuweza kutafsiriwa",
    "Translation copied to clipboard" : "Tafsiri imenakiliwa kwenye ubao wa kunakili",
    "Translation could not be copied" : "Tafsiri haikuweza kunakiliwa",
    "Translate message" : "Tafsiri ujumbe",
    "Source language to translate from" : "Lugha ya chanzo ya kutafsiri kutoka",
    "Translate from" : "Tafsiri kutoka",
    "Target language to translate into" : "Lugha lengwa ya kutafsiriwa",
    "Translate to" : "Tafsiri kwa ",
    "Translating" : "Inatafsiri",
    "Copy translated text" : "Nakili maandishi yaliyotafsiriwa",
    "Reschedule" : "Reschedule",
    "Send now" : "Tuma sasa",
    "Message read by everyone who shares their reading status" : "Ujumbe unaosomwa na kila mtu anayeshiriki hali yake ya usomaji",
    "Message sent" : "Ujumbe umetumwa",
    "Sent without notification" : "Imetumwa bila arifa",
    "Deleting message" : "Inafuta ujumbe",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Ujumbe umefutwa, lakini roboti au Matterbridge imesanidiwa na ujumbe unaweza kuwa tayari kusambazwa kwa huduma zingine.",
    "Message deleted successfully" : "Ujumbe umefutwa kwa mafanikio",
    "Message could not be deleted because it is too old" : "Ujumbe haukuweza kufutwa kwa sababu ni wa zamani sana",
    "Only normal chat messages can be deleted" : "Ni ujumbe wa kawaida tu wa gumzo unaweza kufutwa",
    "An error occurred while deleting the message" : "Hitilafu ilitokea wakati wa kufuta ujumbe",
    "Pinned" : "Pinned",
    "Your browser does not support playing audio files" : "Kivinjari chako hakiungi faili za sauti",
    "Contact" : "Mawasiliano",
    "{stack} in {board}" : "{stack} katika {board}",
    "Deck Card" : "Kadi ya Deck ",
    "Remove {fileName}" : "Ondoa {fileName}",
    "Open this location in OpenStreetMap" : "Fungua eneo hili katika OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n reply","%n majibu"],
    "Sending message" : "Kutuma ujumbe",
    "Failed to send the message. Click to try again" : "Imeshindwa kutuma ujumbe. Bofya ili kujaribu tena",
    "Not enough free space to upload file" : "Hakuna nafasi ya kutosha ya kupakia faili",
    "You cannot send messages to this conversation at the moment" : "Huwezi kutuma ujumbe kwa mazungumzo haya kwa sasa",
    "Could not update the message" : "Haikuweza kusasisha ujumbe",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Poll draft • %n option","Rasimu ya kura • chaguo %n"],
    "_%n vote_::_%n votes_" : ["%n vote","%n kura"],
    "Edit poll draft" : "Hariri rasimu ya kura ya maoni",
    "Delete poll draft" : "Futa rasimu ya kura ya maoni",
    "Open poll" : "Kura ya wazi",
    "See results" : "Ona matokeo",
    "Reactions" : "Miitikio",
    "No permission to post reactions in this conversation" : "Hakuna ruhusa ya kuchapisha maoni katika mazungumzo haya",
    "and {participant}" : "na {participant}",
    "_and %n other participant_::_and %n other participants_" : ["and %n other participant","na %n washiriki wengine"],
    "Show all reactions" : "Onesha miitikio yote",
    "Add more reactions" : "Ongeza miitikio zaidi",
    "Show or collapse system messages" : "Onyesha au ukunje ujumbe wa mfumo",
    "No messages" : "Hakuna jumbe",
    "All messages have expired or have been deleted." : "Barua pepe zote zimeisha muda wake au zimefutwa.",
    "{author} (pinned by you)" : "{author} (pinned by you)",
    "Unpin" : "Bandua",
    "Cancel search" : "Ghairi utafutaji",
    "Add a phone number" : "Ongeza namba ya simu",
    "Error: A password is required to create the conversation." : "Hitilafu: Nenosiri linahitajika ili kuunda mazungumzo.",
    "All set, the conversation \"{conversationName}\" was created." : "Baada ya yote, mazungumzo \"{conversationName}\" yaliundwa.",
    "Create a new group conversation" : "Unda mazungumzo mapya ya kikundi",
    "Add participants" : "Ongeza washiriki",
    "Maximum length exceeded ({maxlength} characters)" : "Urefu wa juu zaidi umepitwa (herufi {maxlength})",
    "Conversation visibility" : "Mwonekano wa mazungumzo",
    "Allow guests to join via link" : "Ruhusu wageni kujiunga kupitia kiungo",
    "Enter password" : "Ingiza nenosiri",
    "This conversation has been locked" : "Mazungumzo haya yamefungwa",
    "No permission to post messages in this conversation" : "Hakuna ruhusa ya kutuma ujumbe katika mazungumzo haya",
    "Joining conversation …" : "Inajiunga na mazungumzo...",
    "Write a message without notification" : "Andika ujumbe bila arifa",
    "Create a thread silently" : "Unda mjadal;a kimya kimya",
    "Create a thread" : "Unda mjadala",
    "Send message silently" : "Tuma ujumbe kimya kimya",
    "Send message" : "Tuma ujumbe",
    "Send without notification" : "Tuma bila arifa",
    "The participant will not be notified about new messages" : "Mshiriki hatataarifiwa kuhusu ujumbe mpya",
    "Participants will not be notified about new messages" : "Washiriki hawatajulishwa kuhusu ujumbe mpya",
    "Thread title is required" : "Kichwa cha mjadala kinahitajika",
    "Message text is required" : "Ujumbe wa maandishi unahitajika",
    "The message could not be edited" : "Ujumbe hauwezi kuhaririwa",
    "File to share" : "Faili la kushirikisha",
    "File upload is not available in this conversation" : "Upakiaji wa faili haupatikani katika mazungumzo haya",
    "Add emoji" : "Ongeza emoji",
    "Adding a mention will only notify users who did not read the message." : "Kuongeza mtajo kutaarifu watumiaji ambao hawakusoma ujumbe pekee.",
    "Thread title" : "Kichwa cha mjadala",
    "Send later" : "Tuma baadaye",
    "Cancel editing" : "Ghairi uhariri",
    "Schedule message" : "Schedule message",
    "{user} is out of office and might not respond." : "{user} yuko nje ya ofisi na anaweza asijibu.",
    "Absence period: {startDate} - {endDate}" : "Kipindi cha kutokuwepo: {startDate} - {endDate}",
    "Replacement:" : "Uingizwaji:",
    "Share from {nextcloud}" : "Shirikisha kutoka {nextcloud}",
    "Share from Files" : "Shirikisha kutoka katika mafaili",
    "Share files to the conversation" : "Shiriki faili kwenye mazungumzo",
    "Upload from device" : "Pakia kutoka katika kifaa",
    "Create new poll" : "Unda kura mpya",
    "Smart picker" : "Kiteua mahiri",
    "Record voice message" : "Rekodi ujumbe wa sauti",
    "End recording and send" : "Maliza kurekodi na utume",
    "Dismiss recording" : "Ondoa kurekodi",
    "Access to the microphone was denied" : "Ufikiaji wa maikrofoni ulikataliwa",
    "Microphone either not available or disabled in settings" : "Maikrofoni haipatikani au imezimwa katika mipangilio",
    "Error while recording audio" : "Hitilafu wakati wa kurekodi sauti",
    "Generating summary of unread messages …" : "Inazalisha muhtasari wa ujumbe ambao haujasomwa ...",
    "Summary is AI generated and might contain mistakes" : "Muhtasari umetolewa na AI na unaweza kuwa na makosa",
    "Error occurred during a summary generation" : "Hitilafu ilitokea wakati wa uzalishaji wa muhtasari",
    "New file" : "Faili mpya",
    "Blank" : "Mabano",
    "Error while creating file" : "Hitilafu wakati wa kuunda faili",
    "Create and share a new file" : "Unda na ushiriki faili mpya",
    "Name of the new file" : "Jina la faili mpya",
    "Create file" : "Unda faili",
    "Someone is typing …" : "Mtu fulani anachapa",
    "{user1} is typing …" : "{user1} anachapa",
    "{user1} and {user2} are typing …" : "{user1} na {user2} wanachapa",
    "{user1}, {user2} and {user3} are typing …" : "{user1},{user2} na {user3} wanachapa...",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} and %n other are typing …","{user1}, {user2}, {user3} na %n wengine wanachapa …"],
    "Add more files" : "Oneza faili zaidi",
    "Send" : "Tuma",
    "In this conversation <strong>{user}</strong> can:" : "Katika mazungumzo haya <strong>{user}</strong> anaweza:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Badilisha ruhusa chaguomsingi kwa washiriki <strong>{conversationName}</strong>",
    "Start a call" : "Anzisha simu",
    "Skip the lobby" : "Ruka kushawishi",
    "Can post messages and reactions" : "Inaweza kuchapisha ujumbe na maoni",
    "Enable the microphone" : "Washa maikrofoni",
    "Enable the camera" : "Washa kamera",
    "Share the screen" : "Shiriki skrini",
    "Update permissions" : "Sasisha ruhusa",
    "Updating permissions" : "Inasasisha ruhusa",
    "No poll drafts" : "Hakuna rasimu za kura",
    "There is no poll drafts yet saved for this conversation" : "Bado hakuna rasimu za kura zilizohifadhiwa kwa mazungumzo haya",
    "Create poll in {name}" : "Unda kura ya maoni katika {name}",
    "Create poll" : "Tengeneza kura ya maoni",
    "Error while importing poll" : "Hitilafu wakati wa kuleta kura ya maoni",
    "Question" : "Swali",
    "Ask a question" : "Uliza swali",
    "Import draft from file" : "Ingiza rasimu kutoka kwenye faili",
    "Answers" : "Majibu",
    "Answer {option}" : "Jibu {option}",
    "Delete poll option" : "Futa chaguo la kura",
    "Add answer" : "Ongeza jibu",
    "Settings" : "Mipangilio",
    "Anonymous poll" : "Kura ya maoni isiyojulikana",
    "Multiple answers" : "Majibu mengi",
    "Save as draft" : "Hifadhi kama rasimu",
    "Export draft to file" : "Hamisha rasimu hadi faili",
    "You voted for this option" : "Ulipigia kura chaguo hili",
    "End poll" : "Maliza kura",
    "Change your vote" : "Badilisha kura yako",
    "Results" : "Matokeo",
    "Voted participants" : "Washiriki waliopiga kura",
    "Send a message to \"{roomName}\"" : "Tuma ujumbe kwa \"{roomName}\"",
    "Hide list of participants" : "Ficha orodha ya washiriki",
    "Show list of participants" : "Onesha orodha ya washiriki",
    "Assistance requested in {roomName}" : "Usaidizi ulioombwa {roomName}",
    "The message was sent to \"{roomName}\"" : "Ujumbe ulitumwa kwa \"{roomName}\"",
    "Dismiss request for assistance" : "Ondoa ombi la usaidizi",
    "Send message to room" : "Tuma ujumbe kwenye chumba",
    "Back to main room" : "Rudi kwenye chumba kuu",
    "Back to your room" : "Rudi kwenye chumba chako",
    "Message all rooms" : "Tuma ujumbe kwenye vyumba vyote",
    "Start session" : "Anza kipindi",
    "Start a call before you start a breakout room session" : "Anza simu kabla ya kuanza kikao cha chumba cha kujitenga",
    "Stop session" : "Simamisha kipindi",
    "The message was sent to all breakout rooms" : "Ujumbe ulitumwa kwa vyumba vyote vya vikundi vidogo",
    "Send a message to all breakout rooms" : "Tuma ujumbe kwa vyumba vyote vya vikundi vidogo",
    "Breakout rooms are not started" : "Vyumba vya kujitenga havijaanza",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Simu zisizo na utendakazi wa hali ya juu zinaweza kusababisha matatizo ya muunganisho na upakiaji wa juu kwenye vifaa. {linkstart}Pata maelezo zaidi{linkend}",
    "Talk setup incomplete" : "Usanidi wa Talk haujakamilika",
    "Disable lobby" : "Zima kushawishi",
    "Settings for participant \"{user}\"" : "Mipangilio ya mshiriki \"{user}\"",
    "Participant \"{user}\"" : "Mshiriki \"{user}\"",
    "moderator" : "moderator",
    "bot" : "bot",
    "guest" : "mgeni",
    "Ringing …" : "Inaita …",
    "Call rejected" : "Sime imekataliwa",
    "{time} talking …" : "{time} anazungumza …",
    "{time} talking time" : "{time}muda wa kuzungumza ",
    "Raised their hand" : "Walinyanyua mkono wao",
    "Joined with video" : "Imeunganishwa na video",
    "Joined via phone" : "Imejiunga kupitia simu",
    "Joined with audio" : "Imeunganishwa na sauti",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Maandishi lazima yawe chini ya au sawa na urefu wa vibambo {maxLength}. Maandishi yako ya sasa yana urefu wa vibambo {charactersCount}.",
    "Remove group and members" : "Ndoa kundi na wanachama",
    "Remove team and members" : "Ondoa timu na wanachama",
    "Remove participant" : "Ondoa washiriki",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Je, kweli unataka kuondoa kikundi \"{displayName}\" na wanachama wake kwenye mazungumzo haya?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Je, ungependa kuondoa timu \"{displayName}\" na wanachama wake kwenye mazungumzo haya?",
    "Do you really want to remove {displayName} from this conversation?" : "Je, kweli unataka kuondoa {displayName} kwenye mazungumzo haya?",
    "Notification was sent to {displayName}" : "Arifa ilitumwa kwa {displayName}",
    "Could not send notification to {displayName}" : "Haikuweza kutuma arifa kwa {displayName}",
    "Permissions granted to {displayName}" : "Ruhusa iliyotolewa kwa {displayName}",
    "Could not modify permissions for {displayName}" : "Haikuweza kubadilisha ruhusa za {displayName}",
    "Permissions removed for {displayName}" : "Ruhusa zimeondolewa kwa {displayName}",
    "Permissions set to default for {displayName}" : "Ruhusa zimewekwa kwa chaguo-msingi kwa {displayName}",
    "Phone number could not be hung up" : "Nambari ya simu haikuweza kukatwa",
    "Phone number could not be put on hold" : "Nambari ya simu haikuweza kuwekwa kwenye kusubiri",
    "Phone number could not be muted" : "Nambari ya simu haikuweza kunyamazishwa",
    "Phone number could not be unmuted" : "Nambari ya simu haikuweza kurejeshwa",
    "DTMF message could not be sent" : "Ujumbe wa DTMF haukuweza kutumwa",
    "Phone number copied to clipboard" : "Nambari ya simu imenakiliwa kwenye ubao wa kunakili",
    "Phone number could not be copied" : "Nambari ya simu haikuweza kunakiliwa",
    "in the lobby" : "katika ukumbi",
    "Dial out phone" : "Piga simu nje",
    "Hang up phone" : "Kata simu",
    "Move back to lobby" : "Rudi kwenye kushawishi",
    "Move to conversation" : "Nenda kwenye mazungumzo",
    "Dial-in PIN" : "Piga simu kwa PIN",
    "Demote from moderator" : "Demote from moderator",
    "Promote to moderator" : "Promote to moderator",
    "Resend invitation" : "Tuma tena mwaliko",
    "Send call notification" : "Tuma arifa ya simu",
    "Dial out phone number" : "Piga namba ya simu ya nje",
    "Resume call for phone number" : "Endelea kupiga simu kwa nambari ya simu",
    "Put phone number on hold" : "Weka nambari ya simu kwenye hali ya kusubiri",
    "Unmute phone number" : "Rejesha sauti ya nambari ya simu",
    "Mute phone number" : "Nyamazisha nambari ya simu",
    "Copy phone number" : "Nakili nambari ya simu",
    "Reset custom permissions" : "Weka upya ruhusa maalum",
    "Grant all permissions" : "Toa ruhusa zote",
    "Remove all permissions" : "Ondoa ruhusa zote",
    "Also ban from this conversation" : "Pia piga marufuku kutoka kwa mazungumzo haya",
    "Internal note (reason to ban)" : "Ujumbe wa ndani (reason to ban)",
    "Remove" : "Ondoa",
    "Permissions modified for {displayName}" : "Ruhusa zimerekebishwa kwa {displayName}",
    "Add users, groups or teams" : "Ongeza watumiaji, vikundi au timu",
    "Add users or groups" : "Ongeza watumiaji au vikundi",
    "Add users or teams" : "Ongeza watumiaji au timu",
    "Add users" : "Ongeza watumiaji",
    "Add groups or teams" : "Ongeza vikundi au timu",
    "Add groups" : "Ongeza vikundi",
    "Add teams" : "Ongeza timu",
    "Add other sources" : "Ongeza vyanzo vingine",
    "Add emails" : "Ongeza barua pepe",
    "Integrations" : "Ujumuishaji",
    "Add federated users" : "Ongeza watumiaji walioshirikishwa",
    "Searching …" : "Inatafuta",
    "Search for more users" : "Tafuta watumiaji zaidi",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Unaweza kutafuta au kuongeza washiriki kupitia jina, barua pepe, au Kitambulisho cha Cloud Shirikishi",
    "Search or add participants" : "Tafuta au ongeza washiriki",
    "Invitation was sent to {actorId}" : "Mwaliko ulitumwa kwa {actorId}",
    "An error occurred while adding the participants" : "Hitilafu ilitokea wakati wa kuongeza washiriki",
    "A new group conversation with selected participant will be created" : "Mazungumzo mapya ya kikundi na mshiriki aliyechaguliwa yataundwa",
    "Participants" : "Washiriki",
    "Participants ({count})" : "Washiriki ({count})",
    "Open chat" : "Gumzo ya wazi",
    "You have new unread messages in the chat." : "Una jumbe mpya ambazo hazijasomwa kwenye gumzo.",
    "You have been mentioned in the chat." : "Umetajwa kwenye gumzo.",
    "Search messages" : "Tafuta jumbe",
    "Chat" : "Gumzo",
    "Details" : "Maelezo ya kina",
    "Shared items" : "Vipengele vilivyoshirikiwa",
    "Search in {name}" : "Tafuta katika {name}",
    "Threads in {name}" : "Mijadala katika {name}",
    "{actor} in {conversation}" : "{actor} katika {conversation}",
    "Search messages …" : "Tafuta jumbe …",
    "Search options" : "Tafuta machaguo",
    "From User" : "Kutoka kwa mtumiaji",
    "Since" : "Tangu",
    "Until" : "Mpaka",
    "No results found" : "Hakuna matokeo yaliyopatikana",
    "Load more results" : "Pakia matokeo zaidi",
    "Recent threads" : "Recent threads",
    "Projects" : "Miradi",
    "No shared items" : "Hakuna vipengele vilivyoshirikiwa",
    "Thread notifications" : "Arifa za mjadala",
    "Thread actions" : "Matendo ya mjadala",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Unga kwenye mazungumzo",
    "No open conversations found" : "Hakuna mazungumzo ya wazi yaliyopatikana",
    "Either there are no open conversations or you joined all of them." : "Labda hakuna mazungumzo ya wazi au umejiunga nayo yote.",
    "Check spelling or use complete words." : "Angalia tahajia au tumia maneno kamili.",
    "Search conversations or users" : "Tafuta mazungumzo au watumiaji",
    "Select conversation" : "Chagua mazungumzo",
    "Number length is not valid" : "Urefu wa nambari sio halali",
    "Region code is not valid" : "Msimbo wa eneo si sahihi",
    "Number length is too short" : "Urefu wa nambari ni mfupi sana",
    "Number length is too long" : "Urefu wa nambari ni mrefu sana",
    "Number is not valid" : "Nambari si halali",
    "Phone numbers" : "Nambari za simu",
    "Display name: {name}" : "Jina la kuonyesha: {name}",
    "Edit display name" : "Badilisha jina la onyesho",
    "Display name (required)" : "Jina la kuonyesha (required)",
    "Save name" : "Hifadhi jina",
    "Error while setting personal setting" : "Hitilafu wakati wa kuweka mipangilio ya kibinafsi",
    "Error while saving sounds setting" : "Hitilafu wakati wa kuhifadhi mpangilio wa sauti",
    "Play sounds when participants join or leave a call" : "Cheza sauti washiriki wanapojiunga au kuacha simu",
    "Notification settings" : "Mipangilio ya arifu",
    "Default language" : "Lugha chaguomsingi",
    "Select location for attachments" : "Chagua eneo la viambatisho",
    "Error while setting attachment folder" : "Hitilafu wakati wa kuweka folda ya kiambatisho",
    "Error while setting read status privacy" : "Hitilafu wakati wa kuweka faragha ya hali ya kusoma",
    "Error while setting typing status privacy" : "Hitilafu wakati wa kuweka faragha ya hali ya kuandika",
    "Error while setting default media state" : "Hitilafu wakati wa kuweka hali chaguo-msingi ya midia",
    "Privacy" : "Faragha",
    "Attachments folder" : "Folda ya viambatisho",
    "Toggle full screen" : "Geuza skrini nzima",
    "Search" : "Tafuta",
    "Focus the chat input" : "Lenga ingizo la gumzo",
    "Unfocus the chat input to use shortcuts" : "Acha kulenga ingizo la gumzo ili kutumia njia za mkato",
    "Edit your last message" : "Hariri ujumbe wako wa mwisho",
    "Shortcuts while in a call" : "Njia za mkato ukiwa kwenye simu",
    "Camera on and off" : "Kamera imewashwa na kuzima",
    "Microphone on and off" : "Maikrofoni imewashwa na kuzima",
    "Raise or lower hand" : "Inua au shusha mkono",
    "Push to talk or push to mute" : "Sukuma kuzungumza au sukuma ili kunyamazisha",
    "Zoom-in / zoom-out a screen share" : "Kuza / kupunguza kushiriki skrini",
    "Mouse wheel" : "Gurudumu la mouse",
    "Start call silently" : "Anza kupiga simu kimya kimya",
    "Start call" : "Anza kupiga simu",
    "End call" : "Kata simu",
    "This call has just ended" : "Simu hii imekatika hivi punde",
    "You will be able to join the call only after a moderator starts it." : "Utaweza kujiunga kwenye Hangout hiyo tu baada ya msimamizi kuianzisha.",
    "End call for everyone" : "Maliza simu kwa kila mtu",
    "Starting the recording" : "Kuanza kurekodi",
    "Recording" : "Inarekodi",
    "The call has been running for one hour." : "Simu imekuwa ikiendeshwa kwa saa moja.",
    "Cancel recording start" : "Ghairi kuanza kurekodi",
    "Stop recording" : "Simamisha kurekodi",
    "Send a reaction" : "Tuma muitikio",
    "React with {reaction}" : "Itikia kwa {reaction}",
    "All tasks done!" : "Shughuli zote zimefanyika!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} of %n task","{done} ya %n shughuli"],
    "Add participants to this call" : "Ongeza washiriki kwenye simu hii",
    "_%n participant in call_::_%n participants in call_" : ["%n participant in call","%n washiriki katika simu"],
    "Scheduled messages" : "Scheduled messages",
    "You are not allowed to enable screensharing" : "Huruhusiwi kuwezesha kushiriki skrini",
    "No screensharing" : "Hakuna kushiriki skrini",
    "Screensharing options" : "Chaguo za kushiriki skrini",
    "Enable screensharing" : "Washa ushiriki wa skrini",
    "Bad sent video and screen quality." : "Ubora mbaya wa video na skrini uliotumwa",
    "Bad sent screen quality." : "Ubora mbaya wa skrini iliyotumwa.",
    "Bad sent video quality." : "Ubora mbaya wa video iliyotumwa.",
    "Bad sent audio, video and screen quality." : "Ubora mbaya wa sauti, video na skrini uliotumwa.",
    "Bad sent audio and screen quality." : "Ubora mbaya wa sauti na skrini uliotumwa",
    "Bad sent audio and video quality." : "Ubora mbaya wa sauti na video uliotumwa.",
    "Bad sent audio quality." : "Ubora mbaya wa sauti uliotumwa.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Muunganisho wako wa intaneti au kompyuta yako ina shughuli nyingi na washiriki wengine huenda wasiweze kuona skrini yako. Ili kuboresha hali hiyo, jaribu kuzima ukungu wa mandharinyuma au video yako wakati unashiriki skrini.",
    "Disable background blur" : "Lemaza ukungu wa mandharinyuma",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Muunganisho wako wa intaneti au kompyuta yako ina shughuli nyingi na washiriki wengine huenda wasiweze kuona skrini yako. Ili kuboresha hali hiyo jaribu kuzima video yako wakati unashiriki skrini.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Muunganisho wako wa intaneti au kompyuta yako ina shughuli nyingi na washiriki wengine huenda wasiweze kuona skrini yako.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Muunganisho wako wa intaneti au kompyuta yako ina shughuli nyingi na washiriki wengine huenda wasiweze kukuona.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Muunganisho wako wa intaneti au kompyuta yako ina shughuli nyingi na washiriki wengine huenda wasiweze kukuelewa na kukuona. Ili kuboresha hali hiyo, jaribu kuzima ukungu wa mandharinyuma au video yako wakati unashiriki skrini.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Muunganisho wako wa intaneti au kompyuta yako ina shughuli nyingi na washiriki wengine huenda wasiweze kukuelewa na kukuona. Ili kuboresha hali hiyo jaribu kuzima video yako wakati unashiriki skrini.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Muunganisho wako wa intaneti au kompyuta yako ina shughuli nyingi na washiriki wengine huenda wasiweze kukuelewa na kuona skrini yako. Ili kuboresha hali jaribu kuzima ushiriki wako wa skrini.",
    "Disable screenshare" : "Disable screenshare",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Muunganisho wako wa intaneti au kompyuta yako ina shughuli nyingi na washiriki wengine huenda wasiweze kukuelewa na kukuona. Ili kuboresha hali hiyo jaribu kuzima ukungu wa mandharinyuma au video yako.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Muunganisho wako wa intaneti au kompyuta yako ina shughuli nyingi na washiriki wengine huenda wasiweze kukuelewa na kukuona. Ili kuboresha hali jaribu kuzima video yako.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Muunganisho wako wa intaneti au kompyuta yako ina shughuli nyingi na washiriki wengine huenda wasiweze kukuelewa.",
    "Screen sharing is not supported by your browser." : "Kushiriki skrini hakutumiki na kivinjari chako.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Kushiriki skrini kunahitaji ukurasa kupakiwa kupitia HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Kushiriki skrini kunahitaji ukurasa kupakiwa kupitia HTTPS.",
    "An error occurred while starting screensharing." : "Hitilafu ilitokea wakati wa kuanza kushiriki skrini.",
    "Select virtual background" : "Chagua mandharinyuma pepe",
    "Show your screen" : "Onesha skrini yako",
    "Stop screensharing" : "Acha kushiriki skrini",
    "Mute others" : "Nyamazisha wengine",
    "Start recording" : "Anza kurekodi",
    "Set up breakout rooms" : "Sanidi vyumba vya vipindi vifupi",
    "Download attendance list" : "Pakua orodha ya mahudhurio",
    "Open Calendar" : "Fungua Kalenda",
    "Remove participant {name}" : "Ondoa mshiriki {name}",
    "Would you like to delete this conversation?" : "Je, ungependa kufuta mazungumzo haya?",
    "Are you sure you want to delete this conversation?" : "Je, una uhakika unataka kufuta mazungumzo haya?",
    "Delete now" : "Futa sasa",
    "Keep" : "Weka",
    "Open dialpad" : "Fungua padi ya kupiga simu",
    "Select a region" : "Chagua eneo",
    "Local time: {time}" : "Muda wa kawaida: {time}",
    "Search …" : "Tafuta...",
    "Message without mention" : "Ujumbe bila kutajwa",
    "Mention myself" : "Nijitaje mwenyewe",
    "Mention everyone" : "Taja kila mtu",
    "Select a conversation" : "Chagua mazungumzo",
    "Select a mode" : "Chagua modi",
    "You do not have permissions to access this conversation." : "Huna ruhusa ya kufikia mazungumzo haya.",
    "Join a different conversation or start a new one." : "Jiunge na mazungumzo tofauti au anza mazungumzo mapya.",
    "The conversation does not exist" : "Mazungumzo hayapo",
    "Join a conversation or start a new one!" : "Jiunge na mazungumzo au anza mazungumzo mapya!",
    "Duplicate session" : "Rudufu kipindi",
    "Creating and joining a conversation with \"{userid}\"" : "Kuunda na kujiunga na mazungumzo na \"{userid}\"",
    "Join a conversation or start a new one" : "Jiunge na mazungumzo au anzisha mapya",
    "Error while joining the conversation" : "Hitilafu wakati wa kujiunga na mazungumzo",
    "Nextcloud URL" : "URL ya Nextcloud ",
    "Nextcloud user" : "Mtumiaji wa Nextcloud ",
    "User password" : "Nenosiri la mtumiaji",
    "Talk conversation" : "Mazungumzo ya Talk",
    "Skip TLS verification" : "Ruka uthibitishaji wa TLS",
    "Matrix server URL" : "URL ya seva ya matrix",
    "User" : "Mtumiaji",
    "Matrix channel" : "Njia ya Matrix ",
    "Mattermost server URL" : "URL ya seva ya Mattermost",
    "Mattermost user" : "Mtumiaji wa Mattermost ",
    "Team name" : "Jina la timu",
    "Channel name" : "Jina la njia",
    "Rocket.Chat server URL" : "URL ya seva ya Rocket.Chat",
    "User name or email address" : "Jina la mtumiaji au anwani ya barua pepe",
    "Rocket.Chat channel" : "Njia ya Rocket.Chat ",
    "Zulip server URL" : "URL ya seva ya Zulip",
    "Bot user name" : "Jina la mtumiaji wa Bot",
    "Bot API key" : "Ufunguo wa Bot API ",
    "Zulip channel" : "Njia ya Zulip ",
    "API token" : "Tokeni ya API ",
    "Slack channel" : "Njia ya Slack ",
    "Server ID or name" : "Kitambulisho cha seva au jina",
    "Channel ID (prefixed with \"ID:\") or name" : "Kitambulisho cha njia (kilichoambishwa na \"ID:\") au jina",
    "Channel" : "Njia ",
    "Login" : "Ingia",
    "Chat ID" : "Kitambulisho cha gumzo",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL ya seva ya IRC (e.g. chat.freenode.net:6667)",
    "Nickname" : "Jina la utani",
    "Connection password" : "Nenosiri la muunganisho",
    "IRC channel" : "Njia ya IRC ",
    "Channel password" : "Nenosiri la njia",
    "NickServ nickname" : "Jina la utani la NickServ",
    "NickServ password" : "Nenosiri la NickServ",
    "Use TLS" : "Tumia TLS",
    "Use SASL" : "Tumia SASL",
    "Tenant ID" : "Kitambulisho cha Tenant ",
    "Client ID" : "Kitambulisho cha mteja",
    "Team ID" : "Kitambulisho cha timu",
    "Thread ID" : "Kitambulisho cha mjadala",
    "XMPP/Jabber server URL" : "URL ya seva ya XMPP/Jabber",
    "MUC server URL" : "URL ya seva ya MUC",
    "Jabber ID" : "Kitambulisho cha Jabber ",
    "Media" : "Midia",
    "Polls" : "Kura",
    "Deck cards" : "Kadi za Deck",
    "Voice messages" : "Jumbe za sauti",
    "Locations" : "Maeneo",
    "Call recordings" : "Rekodi za simu",
    "Audio" : "Sauti",
    "Show all media" : "Onesha media zote",
    "Show all files" : "Onesha faili zote",
    "Show all polls" : "Onesha kura zote",
    "Show all deck cards" : "Onesha kadi zote za deck",
    "Show all voice messages" : "Onesha jumbe zote za sauti",
    "Show all locations" : "Onesha maeneo yote",
    "Show all call recordings" : "Onesha rekodi zote",
    "Show all audio" : "Onesha sauti zote",
    "Show all other" : "Onesha wengine wote",
    "Follow conversation settings" : "Fuata mipangilio ya mazungumzo",
    "Group" : "Kundi",
    "Team" : "Timu",
    "You reconnected to the call" : "Umeunganisha tena kwenye simu",
    "{actor} reconnected to the call" : "{actor} ameunganishwa tena kwenye simu",
    "You added {user0} and {user1}" : "Umeongeza {user0} na {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["You added {user0}, {user1} and %n more participant","Umeongeza {user0}, {user1} na washiriki %n zaidi"],
    "An administrator added you and {user0}" : "Msimamizi alikuongeza wewe na {user0}",
    "{actor} added you and {user0}" : "{actor} alikuongeza wewe na {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["An administrator added you, {user0} and %n more participant","Msimamizi alikuongeza wewe, {user0} na washiriki %n zaidi"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} added you, {user0} and %n more participant","{actor} alikuongeza wewe, {user0} na washiriki %n zaidi"],
    "An administrator added {user0} and {user1}" : "Msimamizi ameongeza {user0} na {user1}",
    "{actor} added {user0} and {user1}" : "{actor} aliongeza {user0} na {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["An administrator added {user0}, {user1} and %n more participant","Msimamizi aliongeza {user0}, {user1} na washiriki %n zaidi"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} added {user0}, {user1} and %n more participant","{actor} aliongeza {user0}, {user1} na washiriki %n zaidi"],
    "You removed {user0} and {user1}" : "Umewaondoa {user0} na {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["You removed {user0}, {user1} and %n more participant","Umewaondoa {user0}, {user1} na washiriki %n zaidi"],
    "An administrator removed you and {user0}" : "Msimamizi alikuondoa wewe na {user0}",
    "{actor} removed you and {user0}" : "{actor} alikuondoa wewe na {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["An administrator removed you, {user0} and %n more participant","Msimamizi alikuondoa wewe, {user0} na washiriki %n zaidi"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} removed you, {user0} and %n more participant","{actor} alikuondoa wewe, {user0} na washiriki %n zaidi"],
    "An administrator removed {user0} and {user1}" : "Msimamizi ameondoa {user0} na {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} ameondoa {user0} na {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["An administrator removed {user0}, {user1} and %n more participant","Msimamizi amewaondoa {user0}, {user1} na washiriki %n zaidi"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} removed {user0}, {user1} and %n more participant","{actor} amewaondoa {user0}, {user1} na washiriki %n zaidi"],
    "You and {user0} joined the call" : "Wewe na {user0} mmejiunga kwenye simu",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["You, {user0} and %n more participant joined the call","Wewe, {user0} na washiriki %n zaidi walijiunga kwenye simu"],
    "{user0} and {user1} joined the call" : "{user0} na {user1} walijiunga kwenye simu",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} and %n more participant joined the call","{user0}, {user1} na washiriki %n zaidi walijiunga kwenye simu"],
    "You and {user0} left the call" : "Wewe na {user0} mmeacha simu",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["You, {user0} and %n more participant left the call","Wewe, {user0} na washiriki %n zaidi mmeacha simu"],
    "{user0} and {user1} left the call" : "{user0} na {user1} waliacha simu",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} and %n more participant left the call","{user0}, {user1} na washiriki %n zaidi waliondoka kwenye simu"],
    "You promoted {user0} and {user1} to moderators" : "Ulipandisha {user0} na {user1} kuwa wasimamizi",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["You promoted {user0}, {user1} and %n more participant to moderators","Ulipandisha {user0}, {user1} na washiriki %n zaidi kuwa wasimamizi"],
    "An administrator promoted you and {user0} to moderators" : "Msimamizi alikupandisha cheo wewe na {user0} kuwa wasimamizi",
    "{actor} promoted you and {user0} to moderators" : "{actor} alikupandisha cheo wewe na {user0} kuwa wasimamizi",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["An administrator promoted you, {user0} and %n more participant to moderators","Msimamizi alikupandisha daraja wewe, {user0} na washiriki %n zaidi kuwa wasimamizi"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} promoted you, {user0} and %n more participant to moderators","{actor} alikupandisha cheo, {user0} na washiriki %n zaidi kuwa wasimamizi"],
    "An administrator promoted {user0} and {user1} to moderators" : "Msimamizi aliwapandisha hadhi {user0} na {user1} kuwa wasimamizi",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} aliwapandisha hadhi {user0} na {user1} kuwa wasimamizi",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["An administrator promoted {user0}, {user1} and %n more participant to moderators","Msimamizi alikweza {user0}, {user1} na washiriki %n zaidi kuwa wasimamizi"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} promoted {user0}, {user1} and %n more participant to moderators","{actor} aliwapandisha hadhi {user0}, {user1} na washiriki %n zaidi kuwa wasimamizi"],
    "You demoted {user0} and {user1} from moderators" : "Umeshusha {user0} na {user1} kutoka kwa wasimamizi",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["You demoted {user0}, {user1} and %n more participant from moderators","Umeshusha hadhi kwa {user0}, {user1} na washiriki %n zaidi kutoka kwa wasimamizi"],
    "An administrator demoted you and {user0} from moderators" : "Msimamizi amekushusha wewe na {user0} kutoka kwa wasimamizi",
    "{actor} demoted you and {user0} from moderators" : "{actor} amekushusha wewe na {user0} kutoka kwa wasimamizi",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["An administrator demoted you, {user0} and %n more participant from moderators","Msimamizi amekushusha cheo wewe, {user0} na washiriki %n zaidi kutoka kwa wasimamizi"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} demoted you, {user0} and %n more participant from moderators","{actor} amekushusha cheo wewe, {user0} na washiriki %n zaidi kutoka kwa wasimamizi"],
    "An administrator demoted {user0} and {user1} from moderators" : "Msimamizi ameshusha hadhi {user0} na {user1} kutoka kwa wasimamizi",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} ameshusha daraja {user0} na {user1} kutoka kwa wasimamizi",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["An administrator demoted {user0}, {user1} and %n more participant from moderators","Msimamizi amewashusha daraja {user0}, {user1} na washiriki %n zaidi kutoka kwa wasimamizi"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} demoted {user0}, {user1} and %n more participant from moderators","{actor} amewashusha daraja {user0}, {user1} na washiriki %n zaidi kutoka kwa wasimamizi"],
    "You:" : "Wewe:",
    "You: {lastMessage}" : "Wewe: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(imehaririwa na wewe)",
    "(edited by a deleted user)" : "(imehaririwa na mtumiaji aliyefutwa)",
    "(edited by {moderator})" : "(imeharirirwa na {moderator})",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Unajaribu kujiunga na mazungumzo huku kipindi kinachoendelea kwenye dirisha au kifaa kingine. Hii kwa sasa haitumiki na Nextcloud Talk. Unataka kufanya nini?",
    "Leave this page" : "Ondoka katika ukurasa huu",
    "Join here" : "Jiunge hapa",
    "Deck card has been posted to {conversation}" : "Kadi ya Deck imechapishwa {conversation}",
    "An error occurred while posting deck card to conversation" : "Hitilafu ilitokea wakati wa kuchapisha kadi ya sitaha kwenye mazungumzo",
    "Post to a conversation" : "Chapisha kwenye mazungumzo",
    "Post to conversation" : "Chapisha kwenye mazungumzo",
    "The recording failed. Please contact your administrator." : "Imeshindwa kurekodi. Tafadhali wasiliana na msimamizi wako.",
    "Location has been posted to {conversation}" : "Mahali pamechapishwa {conversation}",
    "An error occurred while posting location to conversation" : "Hitilafu ilitokea wakati wa kuchapisha eneo kwenye mazungumzo",
    "Share to a conversation" : "Shiriki kwenye mazungumzo",
    "Share to conversation" : "Shiriki kwenye mazungumzo",
    "In conversation" : "Katika mazungumzo",
    "Search in conversation: {conversation}" : "Tafuta katika mazungumzo {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Maombi yako yamezuiliwa kwa sasa kutokana na ulinzi wa nguvu za kikatili",
    "Error while clearing conversation history" : "Hitilafu wakati wa kufuta historia ya mazungumzo",
    "Error occurred while allowing guests" : "Hitilafu ilitokea wakati wa kuwaruhusu wageni",
    "Error occurred while disallowing guests" : "Hitilafu ilitokea wakati wa kutowaruhusu wageni",
    "Error occurred when restricting the conversation to moderator" : "Hitilafu ilitokea wakati wa kuzuia mazungumzo kuwa msimamizi",
    "Error occurred when opening the conversation to everyone" : "Hitilafu ilitokea wakati wa kufungua mazungumzo kwa kila mtu",
    "Conversation password has been saved" : "Nenosiri la mazungumzo limehifadhiwa",
    "Conversation password has been removed" : "Nenosiri la mazungumzo limeondolewa",
    "Error occurred while saving conversation password" : "Hitilafu ilitokea wakati wa kuhifadhi nenosiri la mazungumzo",
    "Call recording is starting." : "Kurekodi simu kunaanza.",
    "Call recording stopped while starting." : "Kurekodi simu kumesimamishwa wakati wa kuanza.",
    "Call recording stopped. You will be notified once the recording is available." : "Kurekodi simu kumesimamishwa. Utaarifiwa mara rekodi itakapopatikana.",
    "Conversation picture set" : "Picha ya mazungumzo imewekwa",
    "Conversation picture deleted" : "Picha ya mazungumzo imefutwa",
    "Could not delete the conversation picture" : "Haikuweza kufuta picha ya mazungumzo",
    "Could not remove the automatic expiration" : "Haikuweza kuondoa muda wa kuisha kiotomatiki",
    "Could not post message: {errorMessage}" : "Haikuweza kuchapisha ujumbe: {errorMessage}",
    "Participant is banned successfully" : "Mshiriki amepigwa marufuku kwa mafanikio",
    "Error while banning the participant" : "Hitilafu wakati wa kupiga marufuku mshiriki",
    "An error occurred while fetching the participants" : "Hitilafu ilitokea wakati wa kuleta washiriki",
    "Could not send invitation to {actorId}" : "Haikuweza kutuma mwaliko kwa {actorId}",
    "Invitations sent" : "Mialiko imetumwa",
    "Error occurred when sending invitations" : "Hitilafu ilitokea wakati wa kutuma mialiko",
    "Failed to join the conversation." : "Imeshindwa kujiunga kwenye mazungumzo.",
    "An error occurred while creating breakout rooms" : "Hitilafu imetokea wakati wa kuunda vyumba vya vipindi vifupi",
    "An error occurred while re-ordering the attendees" : "Hitilafu ilitokea wakati wa kuagiza upya waliohudhuria",
    "An error occurred while deleting breakout rooms" : "Hitilafu ilitokea wakati wa kufuta vyumba vya vipindi vifupi",
    "An error occurred while starting breakout rooms" : "Hitilafu ilitokea wakati wa kuanzisha vyumba vya vipindi vifupi",
    "An error occurred while stopping breakout rooms" : "Hitilafu ilitokea wakati wa kusimamisha vyumba vya vipindi vifupi",
    "An error occurred while sending a message to the breakout rooms" : "Hitilafu ilitokea wakati wa kutuma ujumbe kwenye vyumba vya vipindi vifupi",
    "An error occurred while requesting assistance" : "Hitilafu ilitokea wakati wa kuomba usaidizi",
    "An error occurred while resetting the request for assistance" : "Hitilafu ilitokea wakati wa kuweka upya ombi la usaidizi",
    "An error occurred while joining breakout room" : "Hitilafu ilitokea wakati wa kujiunga na chumba cha vipindi vifupi",
    "Failed to rename the thread" : "Imeshindwa kubadilisha jina la mjadala",
    "Error fetching upcoming events" : "Hitilafu katika kuleta matukio yajayo",
    "Error fetching upcoming reminders" : "Hitilafu katika kuleta vikumbusho vijavyo",
    "An error occurred while accepting an invitation" : "Hitilafu ilitokea wakati wa kukubali mwaliko",
    "An error occurred while rejecting an invitation" : "Hitilafu ilitokea wakati wa kukataa mwaliko",
    "{guest} (guest)" : "{guest} (mgeni)",
    "Poll draft has been saved" : "Rasimu ya kura imehifadhiwa",
    "An error occurred while saving the draft" : "Hitilafu imetokea wakati wa kuhifadhi rasimu",
    "An error occurred while submitting your vote" : "Hitilafu ilitokea wakati wa kuwasilisha kura yako",
    "An error occurred while ending the poll" : "Hitilafu ilitokea wakati wa kumalizia kura",
    "An error occurred while deleting the poll draft" : "Hitilafu ilitokea wakati wa kufuta rasimu ya kura",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Kura ya \"{name}\" iliundwa na {user}. Bofya ili kupiga kura",
    "Failed to add reaction" : "Imeshindwa kuongeza mwitikio",
    "Failed to remove reaction" : "Imeshindwa kuondoa mwitikio",
    "Error while uploading file \"{fileName}\"" : "Hitilafu wakati wa kupakia faili \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Hakuna nafasi ya kutosha ya kupakia faili \"{fileName}\"",
    "You are not allowed to share files" : "Hauruhusiwi kushiriki faili",
    "Error while sharing file" : "Hitilafu wakati wa kushirikisha faili",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Kivinjari unachotumia hakitumiki kikamilifu na Nextcloud Talk. Tafadhali tumia toleo jipya zaidi la Mozilla Firefox, Microsoft Edge, Google Chrome, Opera au Apple Safari.",
    "_In %n hour_::_In %n hours_" : ["In %n hour","Katika %n masaa"],
    "_%n minute _::_%n minutes_" : ["%n minute ","%ndakika "],
    "In {hours} and {minutes}" : "Katika {hours} na {minutes}",
    "_In %n minute_::_In %n minutes_" : ["In %n minute","Katika %n dakika"],
    "Later today – {timeLocale}" : "Baadaye leo-{timeLocale}",
    "Tomorrow – {timeLocale}" : "Kesho-{timeLocale}",
    "This weekend – {timeLocale}" : "Wikendi-{timeLocale}",
    "Next week – {timeLocale}" : "Wiki ijayo-{timeLocale}",
    "Conversation link copied to clipboard" : "Kiungo cha mazungumzo kimenakiliwa kwenye ubao wa kunakili",
    "The link could not be copied" : "Kiungo hakikuweza kunakiliwa",
    "Error while parsing a PROPFIND error" : "Hitilafu wakati wa kuchanganua hitilafu ya PROPFIND",
    "Sending signaling message has failed" : "Imeshindwa kutuma ujumbe wa kuashiria",
    "Lost connection to signaling server. Trying to reconnect." : "Muunganisho umepoteza kwa seva ya kuashiria. Inajaribu kuunganisha tena.",
    "Lost connection to signaling server." : "Muunganisho umepoteza kwa seva ya kuashiria.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Seva ya kuashiria iliyosanidiwa inahitaji kusasishwa ili iendane na toleo hili la Talk. Tafadhali wasiliana na utawala wako.",
    "Please restart the app." : "Tafadhali anzisha upya programu.",
    "Please reload the page." : "Tafadhali pakia ukurasa upya ",
    "Please try to restart the app." : "Tafadhali jaribu kuanzisha upya programu.",
    "Please try to reload the page." : "Tafadhali jaribu kupakia upya ukurasa.",
    "Do not disturb" : "Acha kusumbua",
    "Away" : "Mbali",
    "Microphone {number}" : "Maikrofoni {number}",
    "Camera {number}" : "Kamera {number}",
    "Speaker {number}" : "Spika {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Unaonekana unaongea huku umenyamazishwa, tafadhali acha kunyamazisha ili wengine wakusikie",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Haikuweza kuanzisha muunganisho na angalau mshiriki mmoja. Seva ya TURN inaweza kuhitajika kwa hali yako. Tafadhali mwombe msimamizi wako aweke mipangilio kufuatia {linkstart}hati hizi{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Hii inachukua muda mrefu kuliko ilivyotarajiwa. Je, ruhusa za midia tayari zimetolewa (au zimekataliwa)? Ikiwa ndio, tafadhali anzisha kivinjari chako upya, kwani sauti na video hazifanyi kazi",
    "Access to microphone & camera is only possible with HTTPS" : "Ufikiaji wa maikrofoni na kamera unawezekana tu kwa HTTPS",
    "Please move your setup to HTTPS" : "Tafadhali hamishia usanidi wako hadi HTTPS",
    "Access to microphone & camera was denied" : "Ufikiaji wa maikrofoni na kamera umekataliwa",
    "WebRTC is not supported in your browser" : "WebRTC haitumiki katika kivinjari chako",
    "Please use a different browser like Firefox or Chrome" : "Tafadhali tumia kivinjari tofauti kama Firefox au Chrome",
    "Error while accessing microphone & camera" : "Hitilafu wakati wa kufikia maikrofoni na kamera",
    "%s Talk on your mobile devices" : "%s Zungumza kwenye vifaa vyako vya mkononi",
    "Join conversations at any time, anywhere, on any device." : "Jiunge na mazungumzo wakati wowote, mahali popote, kwenye kifaa chochote.",
    "Android app" : "Programu ya Android",
    "iOS app" : "Programu ya iOS",
    "__language_name__" : "_lugha_jina_",
    "Webhook Demo" : "Demo ya Webhook ",
    "Call summary (%s)" : "Muhtasari wa simu (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Boti ya muhtasari wa simu huchapisha ujumbe wa muhtasari baada ya simu kuorodhesha washiriki wote na kuelezea majukumu",
    "Tasks" : "Kazi",
    "Notes" : "Madokezo",
    "Reports" : "Taarifa",
    "Decisions" : "Maamuzi",
    "Agenda" : "Ajenda",
    "Call summary" : "Muhtasari wa simu",
    "Call summary - {title}" : "Muhtasari wa simu-{title}",
    "Talk conversation for event" : "Mazungumzo ya Talk kwa tukio",
    "Client Push is installed, this improves the performance of desktop clients." : "Msukumo wa Mteja umewekwa, hii inaboresha utendaji wa wateja wa eneo-kazi.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} haijasakinishwa, hii inaweza kusababisha matatizo ya utendakazi unapotumia wateja wa eneo-kazi.",
    "Next meeting" : "Mkutano ujao",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Ratibu mkutano kutoka kwa kalenda yako. Mazungumzo ya Talk yanahitaji kuwekwa kama eneo ili kuonekana hapa",
    "Join conversations from remote Nextcloud servers" : "Jiunge na mazungumzo kutoka kwa seva za mbali za Nextcloud",
    "Your default media state has been saved" : "Hali yako chaguomsingi ya midia imehifadhiwa",
    "Set reminder for later today" : "Weka kikumbusho cha baadaye leo",
    "Set reminder for tomorrow" : "Weka kikumbusho cha kesho",
    "Set reminder for this weekend" : "Weka kikumbusho cha wikendi hii",
    "Set reminder for next week" : "Weka kikumbusho cha wiki ijayo",
    "Generate summary" : "Tengeneza muhtasari",
    "Open poll • You voted already" : "Kura ya wazi • Umeshapiga kura",
    "Open poll • Click to vote" : "Fungua kura • Bofya kupiga kura",
    "Poll • Ended" : "Kura ya maoni • Imeisha",
    "Talk recording from {time} ({conversation})" : "Talk inarekodi kutoka {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Poll results • %n vote","Matokeo ya kura • kura %n"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Open poll • %n vote","Kura iliyofunguliwa • kura %n"],
    "Submit vote" : "Wasilisha kura",
    "Your privacy setting has been saved" : "Mipangilio yako ya faragha imehifadhiwa",
    "Your personal setting has been saved" : "Mipangilio yako ya kibinafsi imehifadhiwa",
    "Failed to save sounds setting" : "Imeshindwa kuhifadhi mpangilio wa sauti",
    "Sounds setting saved" : "Mipangilio ya sauti imehifadhiwa",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk ilisasishwa, huwezi kuanzisha au kujiunga na simu.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Ulijiunga kwenye mazungumzo kwenye dirisha au kifaa kingine. Hii kwa sasa haitumiki na Nextcloud Talk kwa hivyo kipindi hiki kilifungwa.",
    "Nextcloud Talk was updated." : "Nextcloud Talk imesasishwa.",
    "Nextcloud is in maintenance mode." : "Nextcloud iko katika hali ya matengenezo.",
    "Nextcloud Talk Federation was updated." : "Nextcloud Talk Federation imesasishwa."
},
"nplurals=2; plural=(n != 1);");
